import React, { Component } from 'react';
import jwtManager from '../lib/jwtManager';
import { NSCartBillingStep } from './NSCartBillingStep';
import { NSDetailOrder } from './NSDetailOrder';
import { NSOrderList } from './NSOrderList';

/**
 * NSAccount description
 *
 * @return {React.Component}
 */
export class NSAccount extends React.Component {
    constructor(props) {
        super(props);
        this.cssHook = '';
        this.jsxHook = undefined;
    }
    async logout() {
        await jwtManager.remove();
        window.location.pathname = '/';
    }

    render() {
        const {
            slug, page, numOrder, client,
        } = this.props;
        let myAccountView;
        const ordersSlug = 'orders';
        // const RGPDSlug = "RGPD";
        if (!slug) myAccountView = <NSCartBillingStep fromCart={false} />;
        else if (slug == ordersSlug && numOrder) {
            myAccountView = (
                <NSDetailOrder client={client} numOrder={numOrder} />
            );
        } else if (slug == ordersSlug && !numOrder) { myAccountView = <NSOrderList client={client} page={page} />; }
        // else if (slug == RGPDSlug) myAccountView = <RGPD />;

        return (
            <div className="wrapperAccount">
                <h1>Informations du compte</h1>
                <section className="content container">
                    <div className="row">
                        <div
                            className="col-md-4 fixedMenu"
                            style={{ maxWidth: '250px', height: '200px' }}
                        >
                            <h2>MON COMPTE</h2>
                            <a href="/account">
                                <div>
                                    <span className={!slug && 'bold'}>
                                        Informations du compte
                                    </span>
                                </div>
                            </a>
                            <a href={`/account/${ordersSlug}/1`}>
                                <div>
                                    <span
                                        className={slug == ordersSlug && 'bold'}
                                    >
                                        Mes commandes
                                    </span>
                                </div>
                            </a>
                            {
                                // <Link href={`/account/${RGPDSlug}`}>
                                //     <div>
                                //         <span className={slug == RGPDSlug && "bold"}>RGPD</span>
                                //     </div>
                                // </Link>
                            }
                            <div>
                                <button
                                    style={{
                                        border     : '0',
                                        background : 'transparent',
                                        textAlign  : 'right',
                                        padding    : '0',
                                    }}
                                    type="button"
                                    onClick={this.logout}
                                >
                                    <span>Se déconnecter</span>
                                </button>
                            </div>
                        </div>
                        <div className="col-md-8">{myAccountView}</div>
                    </div>
                </section>
                <style jsx="true">{`
                    .bold {
                        font-weight: bold;
                    }
                    .wrapperAccount {
                        text-align: center;
                        width: 100%;
                    }
                    .content {
                        margin-top: 75px;
                        display: flex;
                        justify-content: center;
                    }
                    h1 {
                        font-size: 30px;
                        color: #fdbc58;
                    }
                    .fixedMenu {
                        background: #fdbc58;
                        color: black;
                        border-radius: 2px;
                        box-shadow: 0px 0px 10px #aaa;
                        border-bottom: 4px solid #b58140;
                        padding-bottom: 10px;
                        height: fit-content;
                        margin-top: 134px;
                    }
                    .fixedMenu > h2 {
                        border-bottom: 1px dashed black;
                        border-width: 2px;
                        margin: 15px 15px 0px 15px;
                        padding-bottom: 5px;
                    }
                    .fixedMenu div {
                        border-bottom: 1px dashed black;
                        border-width: 2px;
                        margin: 0px 15px 0px 15px;
                        padding: 5px 0px 5px 0px;
                        text-align: start;
                    }
                    .fixedMenu div:hover,
                    .fixedMenu button:hover {
                        cursor: pointer;
                        color: white;
                        font-weight: bold;
                    }
                    .row {
                        width: 100%;
                    }
                    @media (max-width: 768px) {
                        .fixedMenu {
                            max-width: unset !important;
                            margin-bottom: 50px;
                        }
                    }
                    ${this.cssHook};
                `}</style>
                {this.jsxHook}
            </div>
        );
    }
}
