import React, { Component } from 'react';
import axios from 'axios';
import {NSToast} from './NSToast';
import { scrollToTop } from '../lib/helpers';
import { isAuth } from '../lib/isAuth';
import getAPIUrl from '../lib/generateAPIUrl';

export class NSAddress extends Component {
    constructor(props) {
        super(props);
        this.state = {
            ...props,
            // Permet de sauvegarder l'adresse en cours de modification
            address : {
                civility             : '',
                lastname             : '',
                firstname            : '',
                companyName          : '',
                line1                : '',
                line2                : '',
                zipcode              : '',
                city                 : '',
                isoCountryCode       : '',
                phone                : '',
                phone_mobile         : '',
                idx_delivery_address : '',
                idx_billing_address  : ''
            },
            user            : { addresses: [] },
            editMode        : false,
            // address         : { company: {} },
            cart            : {},
            countries       : [],
            isDelivery      : false,
            isBilling       : false,
            selectedCountry : {},
            useSameAddress  : false,
            index           : -1,
            lastCountry     : 'FR',
        };
        this.getParentState = this.getParentState.bind(this);
    }
    /**
     * @returns {object} retourne le state de NSAddress
     */
    getParentState() {
        return this.state;
    }
    async componentDidMount() {
        try {
            const userAuth = await isAuth();
            if (!userAuth.isLogged) throw userAuth;
            const countries = await axios.get(`${getAPIUrl()}territory/countries`);
            this.setState({
                user        : userAuth.client,
                countries   : countries.data,
                lastCountry : userAuth.client.addresses[userAuth.client.delivery_address].isoCountryCode
            });
        } catch (e) {
            NSToast.warn('addresses:error.notConnected', this.props.i18n);
            if (typeof window !== 'undefined') {
                window.location.pathname = window.location.pathname.indexOf('/cart/') > -1 ? '/cart/login' : '/login';
            }
        }
    }

    componentWillReceiveProps(props) {
        this.setState({ ...props });
    }

    addAddress = async (e) => {
        e.preventDefault();
        try {
            const { user, address } = this.state;
            const { idx_delivery_address, idx_billing_address } = address;
            delete address.idx_delivery_address;
            delete address.idx_billing_address;
            address.civility = Number(address.civility);
            if (address._id) {
                const idx = user.addresses.findIndex(adrs => adrs._id === address._id);
                if (idx >= 0) {
                    user.addresses[idx] = address;
                }
            } else {
                delete address._id;
                user.addresses.push(address);
            }
            const res = await axios.put(`${getAPIUrl()}v2/user/addresses`, {
			userId           : user._id,
			billing_address  : (idx_billing_address !== undefined && idx_billing_address !== '' && idx_billing_address !== -1) ? Number(idx_billing_address) : Number(user.billing_address),
			delivery_address : (idx_delivery_address !== undefined && idx_delivery_address !== '' && idx_delivery_address !== -1) ? Number(idx_delivery_address) : Number(user.delivery_address),
			addresses        : user.addresses,
		});
            this.setState({
                user       : res.data, editMode   : false, isBilling  : false, isDelivery : false, address: {}
            }, () => scrollToTop(500));
            NSToast.success('addresses:success.addressUpdateSuccess', this.props.i18n);
        } catch (error) {
            console.error(error);
            NSToast.error('addresses:error.addressUpdateFail', this.props.i18n);
        }
    }
    handleAddressChange = (e, index) => {
        const { address } = this.state;
        if (e.target.name === 'civility') {
            user.civility === e.target.value;
        } else if ((e.target.type === 'checkbox' || e.target.type === 'radio') && e.target.name !== 'civility') {
            return;
        } else if (e.target.name === 'country') {
            address.isoCountryCode = e.target.value;
        } else {
            address[e.target.name] = e.target.value;
        }
        if (this.state.useSameAddress) {
            address[1] = address[0];
        }
        this.setState({ address });
    }

    submitAddresses = async (e) => {
        e.preventDefault();
        try {
            if (this.state.user.addresses.length < 2) { NSToast.warn('addresses:error.mustHaveTwoAddresses', this.props.i18n); return; }
            const addresses = { billing: this.state.user.addresses[this.state.user.billing_address], delivery: this.state.user.addresses[this.state.user.delivery_address] };
            const res = await axios.put(`${getAPIUrl()}v2/cart/addresses`, { cartId: window.localStorage.getItem('cart_id'), addresses });
            if (res.status === 200) {
                window.location.pathname = '/cart/delivery';
            }
        } catch (error) {
            NSToast.error('addresses:error.addAddressToOrderFail', this.props.i18n);
            console.error(error);
        }
    }
    submitCartAddresses = async (e) => {
        e.preventDefault();
        try {
            if (this.state.user.addresses.length < 1) { return NSToast.error('addresses:error_msg.at_least_one_address', this.props.i18n); }
            try {
                const addresses = { billing: this.state.user.addresses[this.state.user.billing_address], delivery: this.state.user.addresses[this.state.user.delivery_address] };
                const res = await axios.put(`${getAPIUrl()}v2/cart/addresses`, { cartId: window.localStorage.getItem('cart_id'), addresses });
                if (res.status === 200) {
                    const prefix = getLangPrefix(this.context.getPageState().nsLanguages, this.props.i18n.language);
                    Router.pushRoute(`${prefix}/cart/delivery`);
                }
            } catch (error) {
                console.error(error);
                if (error.response && error.response.data.code === 'NOT_VALID_ADDRESS') {
                    return NSToast.error(error.response && error.response.data.message);
                }
                return NSToast.error('addresses:error_msg.fail_add_order_address', this.props.i18n);
            }
        } catch (error) {
            NSToast.error('addresses:error_msg.fail_add_order_address', this.props.i18n);
            console.error(error);
        }
    }
    fuseAddresses() {
        const { user } = this.state;
        user.addresses[1] = user.addresses[0];
        this.setState({ user });
    }

    handleUserChange = (event) => {
        const { user } = this.state;
        if (event.target.type === 'radio') {
            user.civility === event.target.value;
        } else if (event.target.name.startsWith('company.')) {
            const [obj, property] = event.target.name.split('.');
            user[obj][property] = event.target.value;
        } else {
            user[event.target.name] = event.target.value;
        }
        this.setState({ user: { ...user } });
    }

    deleteAddress = async (index) => {
        const { user } = this.state;
        let { billing_address, delivery_address } = user;
        if (index < billing_address) {
            billing_address--;
        }
        if (index < delivery_address) {
            delivery_address--;
        }
        user.addresses.splice(index, 1);
        const res = await axios.put(`${getAPIUrl()}v2/user/addresses`, {
            userId    : user._id,
            addresses : user.addresses,
            billing_address,
            delivery_address,
        });
        this.setState({ user: res.data });
    }
}
