import React from 'react';
import axios from 'axios';
import moment from 'moment';
import PropTypes from 'prop-types';
import getAPIUrl from '../lib/generateAPIUrl';

/**
 * @return {React.Component}
 */
export class NSArticles extends React.Component {
    constructor() {
        super();
        this.state = {
            articles    : null,
            openArticle : null
        };
    }

    static contextTypes = { getPageState: PropTypes.func };

    componentDidMount = async () => {
        // API pour charger les articles
        const result = await axios(`${getAPIUrl()}site/news/visible`);
        this.setState({ articles: result.data });
    }

    showMore = async (i) => {
        if (this.state.openArticle == i) return this.setState({ openArticle: null });
        return this.setState({ openArticle: i });
    }

    render() {
        const { articles, openArticle } = this.state;
        if (articles == null) return <div className="nsarticle" />;
        return (
            <div className="nsarticle">
                {
                    articles.length
                        ? articles.map((article, i) => (
                            <div key={i} className="article">
                                <article onClick={() => this.showMore(i)} itemscope="" itemtype="http://schema.org/Article">
                                    <h2 itemprop="headline">{article.title}</h2>
                                    {
                                        openArticle == i
                                            ? (
                                                <div>
                                                    <div itemprop="image" itemscope="" itemtype="http://schema.org/ImageObject">
                                                        <meta itemprop="url" content={article.img} />
                                                        <img src={article.img} width="200" alt={article.title} />
                                                    </div>
                                                    <div itemprop="articleBody" dangerouslySetInnerHTML={{ __html: article.content.text }} />
                                                </div>
                                            )
                                            :                                            <div itemprop="articleBody">{article.content.resume}... </div>
                                    }
                                    <div className="article-date" itemprop="datePublished" content={moment(article.createdAt).format('DD/MM/YYYY, HH:mm:ss')}>
                                        {moment(article.createdAt).format('DD/MM/YYYY, HH:mm:ss')}
                                    </div>
                                </article>
                            </div>
                        ))
                        : 'Aucun article trouvé'
                }

                <link href="/static/css/article.css" rel="stylesheet" />
                <style jsx="true" />
            </div>
        );
    }
}
