import React from 'react';
import Slider from 'react-slick';
import PropTypes from 'prop-types';
import { NSCMS } from './NSCMS';

/**
 * NSBlockSlider - Charge les informations du slider (via son ns-code), affiche les blocs CMS en permettant un slide lattéral
 * @prop ns-code: (string) codes des blocs CMS à afficher
 * @return {React.Component}
 */
export class NSBlockSlider extends React.Component {
    constructor(props, context) {
        super(props, context);
        this.state = {
            nsBlockSlider   : context.getPageState()[`nsBlockSlider_${props['ns-code']}`], // Tableau des données des blocs CMS récupérées depuis le component loader de la page
            autoplay        : props.autoplay || false, // Défilement auto
            arrows          : props.arrows || true, // Flèches de défilement
            adaptiveHeight  : props.adaptiveHeight || false, // Hauteur qui s'adapte en fonction du bloc
            dots            : props.dots || true, // Points de navigation en bas
            draggable       : props.draggable || true // Faire glisser pour défiler 
        };
    }

    static contextTypes = { getPageState: PropTypes.func };

    render() {
        const { nsBlockSlider, autoplay, arrows, adaptiveHeight, dots, draggable } = this.state;
        const settings = {
            autoplay,
            arrows,
            adaptiveHeight,
            dots,
            draggable
        }
        if (!nsBlockSlider) {
            return (
                <div>{this.props.t('common:error.loadDataComponent', { component: 'NSBlockSlider' })}</div>
            );
        }

        return (
            <React.Fragment>
                <link
                    rel="stylesheet"
                    type="text/css"
                    href="/static/slick-1.6.0/slick_and_theme.css"
                />
                <link rel="stylesheet" href="/static/css/slider.css" />
                <div className="NSBlockSlider">
                    <Slider {...settings} style={{ width: '100%' }}>
                        {nsBlockSlider.map(item => (
                            <div key={item._id} style={{ width: '100%' }}>
                                <NSCMS content={item.content} />
                            </div>
                        ))}
                    </Slider>
                </div>
            </React.Fragment>
        );

    }
}