import React from 'react';
import moment from 'moment';
import PropTypes from 'prop-types';
import { getLangPrefix } from '../lib/helpers';

/**
 * NSBlogArticles - Affiche la liste des articles du blog
 * @return {React.Component}
 */
export class NSBlogArticles extends React.Component {
    constructor(props, context) {
        super(props, context);
        this.state = {
            ...props,
            articles: context.getPageState().nsBlogArticles,
            nsLanguages: context.getPageState().nsLanguages
        };
    }

    render() {
        const { articles, nsLanguages } = this.state;
        const lang = this.props.i18n.language;
        const url = typeof window !== 'undefined' ? window.location.origin : '';
        return (
            articles.length ? articles.map(article => (
                <section
                    className="section section--table ns-article" key={article.slug[lang]} itemScope=""
                    itemType="http://schema.org/Article"
                >
                    <div className="shell">
                        <h2 className="section__title">
                            <span itemProp="headline"><a href={`${getLangPrefix(nsLanguages, lang)}/blog/${article.slug[lang]}`}>{article.title}</a></span>
                        </h2>

                        <div itemProp="image" itemScope="" itemType="http://schema.org/ImageObject">
                            <meta itemProp="url" content={`${url}/${article.img}`} />
                        </div>

                        <div className="section__body">
                            <div className="section__inner">
                                <div className="article-date" itemProp="datePublished" content={moment(article.createdAt).format('DD/MM/YYYY - HH[h]mm')}>
                                    {moment(article.createdAt).format('DD/MM/YYYY - HH[h]mm')}
                                </div>
                                <div itemProp="articleBody" className="ns-article-content" dangerouslySetInnerHTML={{ __html: (article.img ? `<img src=${url}/${article.img} alt=${article.img} />` : '') + `${article.content.resume} ... <a href="${getLangPrefix(this.context.getPageState().nsLanguages, lang)}/blog/${article.slug[lang]}">[+]</a>` }} />
                            </div>
                        </div>
                    </div>
                </section>
            )) : this.props.t('common:blog.noArticle')
        );
    }

    static contextTypes = { getPageState: PropTypes.func };
}