import React from 'react';
import ReactHtmlParser, { convertNodeToElement } from 'react-html-parser';
import PropTypes from 'prop-types';
import componentsTags from './_NSconfig';

export class NSCMS extends React.Component {
    constructor(props, context) {
        super(props, context);
        this.state = {
            content : this.getContent(props, context),
            code : props['ns-code'],
            componentsTags
        };
    }

    getContent = (props, context) => {
        return props.content !== ''
                ? props.content
                : context.getPageState()[`nsCms_${props['ns-code']}`] ?
                context.getPageState()[`nsCms_${props['ns-code']}`].content :
                    '';
    }

    componentWillReceiveProps(nextProp) {
        this.setState({ content: this.getContent(nextProp, this.context) });
    }

    transform = (node, index) => {
        if (node && node.name && node.type === 'tag' && this.state.componentsTags[node.name] !== undefined && this.state.componentsTags[node.name]) {
            const component = React.cloneElement(
                this.state.componentsTags[node.name],
                {
                    key : node.name + index,
                    ...node.attribs
                },
            );
            return component;
        } else if (node && node.name === 'textarea') {
            return React.cloneElement(<textarea />, {...node.attribs, className: node.attribs['class-name'], key: `textArea-${index}`})
        } else if (node && node.name === 'ns-cms') {
            const component = React.cloneElement(
                <NSCMS />,
                {
                    key : node.attribs['ns-code'],
                    ...node.attribs
                },
            );
            return component;
        } else if (node && node.name === 'style') {
            return (
                <style
                    key={`style__${index}`}
                    jsx="true"
                    dangerouslySetInnerHTML={{ __html: node.children[0].data }}
                />
            );
        } return convertNodeToElement(node, index, this.transform);
    }

    render() {
        const options = { decodeEntities: true, transform: (node, index) => this.transform(node, index) };
        return this.state.content ? <React.Fragment>{ ReactHtmlParser(this.state.content, options) }</React.Fragment> : (this.props.hide_error ? '' : <div>Impossible d'afficher le bloc CMS !</div>)
    }

    static contextTypes = {
        getPageState: PropTypes.func
    };

    static defaultProps = {
        'ns-code': '',
        content: '',
        modules: [],
        hide_error: false
    };

    static propTypes = { 
        'ns-code': PropTypes.string,
        content: PropTypes.string
    };
}
