import React from 'react';
import axios from 'axios';
import {NSToast} from './NSToast';
import getAPIUrl from '../lib/generateAPIUrl';
import { isAuth } from '../lib/isAuth';
import jwtManager from '../lib/jwtManager';

/**
 * NSCart description
 *
 * /!\ BUG AU NIVEAU DES TOASTS /!\
 *
 * @return {React.Component}
 */
export class NSCart extends React.Component {
    constructor() {
        super();
        this.state = {
            cart       : null,
            taxDisplay : 'ati'
        };
        this.cssHook = '';
        this.jsxHook = undefined;
    }

    async componentDidMount() {
        try {
            const cartId = window
                .localStorage
                .getItem('cart_id');
            if (!cartId || cartId == null) {
                NSToast.warn('cart:error.emptyCart', this.props.i18n);
                return;
            }
            window.addEventListener('discountAdded', async (e) => {
                const id = window.localStorage.getItem('cart_id');
                if (!id) return;
                const result = await axios.post(`${getAPIUrl()}v2/cart/${id}`, { lang: this.props.i18n.language, PostBody: { populate: ['items._id'] } });
                if (result.status === 500) {
                    NSToast.error('cart:error.serverError', this.props.i18n);
                    return;
                } if (result.status === 204) {
                    return;
                }
                // e.detail.error peut valoir true ou false, s'il y a une erreur on enleve l'affichage de la reduction
                this.setState({ cart: result.data, withDiscount: !e.detail.error });
            });
            const result = await axios.post(`${getAPIUrl()}v2/cart/${cartId}`, { lang: this.props.i18n.language, PostBody: { populate: ['items._id'] } });
            if (result.status === 500) {
                NSToast.error('cart:error.serverError', this.props.i18n);
                return;
            }
            if (result.status === 204) {
                return;
            }
            const taxDisplay = jwtManager.getTaxDisplay();
            this.setState({ cart: result.data, taxDisplay });
            const deliveryPrice = await axios.post(`${getAPIUrl()}v2/shipments/filter`, { cart: this.state.cart, lang: this.props.i18n.language });
            if (deliveryPrice) {
                this.setState({ deliveryPrice: deliveryPrice.data > 0 ? <span>{deliveryPrice.data} &euro;</span> : deliveryPrice.data });
            }
        } catch (error) {
            console.error(error);
            this.setState({ error_cart: 'ERREUR LORS DE LA RECUPÉRATION DU PANIER' });
            window.localStorage.removeItem('cart_id');
            // NSToast.error('cart:error.getCartError', this.props.i18n);
        }
    }

    async onChangeQuantity(input, idx) {
        const { cart } = this.state;
        try {
            const quantity = Number(input.target.value);
            // Si on supprime la quantité, on la remet a 1
            if (!quantity) {
                cart.items[idx].quantity = 1;
                return this.setState({ cart });
            }
            const response = await axios.put(`${getAPIUrl()}/v2/cart/updateQty`, {
                item   : { _id: cart.items[idx]._id, quantity },
                cartId : window.localStorage.getItem('cart_id'),
            });
            cart.items[idx].quantity = quantity;
            this.setState({ cart: response.data });
        } catch (error) {
            console.error(error);
            // On remet la valeur a l'état initial si il y a une erreur
            cart.items[idx].quantity = Number(input.target.value);
            this.setState({ cart });
        }
    }

    calculTotalPrice(item) {
        const { taxDisplay } = this.state;
        if (item.quantity >= 5) {
            // return item.price.total.ati = Number(item.price.special.ati * item.quantity).aqlRound(2);
            return Number(item.id.price[taxDisplay].special * item.quantity).aqlRound(2);
        }
        // return item.price.total.ati = Number(item.price.unit.ati * item.quantity).aqlRound(2);
        return Number(item.id.price[taxDisplay].normal * item.quantity).aqlRound(2);
    }

    deleteProduct = async (cart, idx, isGift = false, onSuccess, onError) => {
        try {
            const cartId = window.localStorage.getItem('cart_id');
            const itemId = isGift ? cart.items[idx].children[0] : cart.items[idx].id._id;
            const response = await axios.delete(`${getAPIUrl()}v2/cart/${cartId}/item/${itemId}`);
            if (onSuccess) onSuccess(response.data);
        } catch (error) {
            if (onError) onError(error);
        }
    };

    qtyModifier = async (cart, addOrRemove, idx, isGift = false, onSuccess, onError) => {
        let itemId = '';
        let item = {};
        if (isGift) {
            itemId = cart.items[idx].children[0];
            item = cart.items.find(it => it._id === itemId);
            if (cart.items[idx].quantity === item.quantity && addOrRemove === '+') { return; }
        } else {
            itemId = cart.items[idx]._id;
            item = cart.items.find(it => it._id === itemId);
        }
        try {
            if (addOrRemove === '-' && item.quantity > 1) {
                // Si on baisse la quantité d'un produit qui n'est pas un cadeau et
                // que ce produit a une quantité === a la quantité du cadeau alors on baisse aussi la quantité du cadeau
                if (!isGift) {
                    const oGift = cart.items.find(it => it._id === item.children[0]);
                    if (oGift && oGift.quantity === item.quantity) {
                        oGift.quantity--;
                        await axios.put(`${getAPIUrl()}v2/cart/updateQty`, {
                            item   : { _id: oGift._id, quantity: oGift.quantity },
                            cartId : window.localStorage.getItem('cart_id'),
                        });
                    }
                }
                item.quantity--;
            } else if (addOrRemove === '-' && item.quantity === 1) {
                this.deleteProduct(cart, idx, isGift, onSuccess, onError);
                return;
            } else if (addOrRemove === '+') {
                item.quantity++;
            } else {
                return NSToast.warn('common:error_occured');
            }
            const response = await axios.put(`${getAPIUrl()}v2/cart/updateQty`, {
                item   : { _id: item._id, quantity: item.quantity },
                cartId : window.localStorage.getItem('cart_id'),
            });
            if (onSuccess) onSuccess(response.data); // return updated cart
        } catch (error) {
            console.error(error);
            // Si il y a une erreur on remet la quantity a l'état initial
            if (onError) onError(error);
        }
    };


validateCart = async (cart) => {
    try {
        if (cart === undefined || cart.items === undefined || cart.items.length === 0) return NSToast.error('cart:error.getCartError', this.props.i18n);
        const { isLogged } = await isAuth();
        if (!isLogged) window.location.pathname = '/cart/login'; // Router.pushRoute('/cart/login');
        window.location.pathname = '/cart/address'; // Router.pushRoute('/cart/address');
    } catch (error) {
        console.error(error);
        window.location.pathname = '/cart/login';// Router.pushRoute('/cart/login');
    }
};

async getDeliveryPrice() {
    const deliveryPrice = await axios.post(`${getAPIUrl()}v2/shipments/filter`, {
        cart           : this.state.cart, lang           : this.props.i18n.language, withoutCountry : this.state.countryCode ? this.state.countryCode : 'FR',
    });
    this.setState({ deliveryPrice: deliveryPrice.data.price });
}

render() {
    const { cart, taxDisplay } = this.state;
    if (!cart || !cart.items.length) {
        return (
            <h2 style={{ position: 'relative', height: '100px' }}>
                <span style={{ display: 'none' }} id="no-items">
                        Vous n'avez pas de produit dans votre panier
                </span>
                <div
                    id="loading-spinner"
                    style={{
                        position : 'absolute',
                        top      : '0',
                        zIndex   : '101',
                        left     : '0%',
                        width    : '100%',
                    }}
                >
                    <div
                        style={{
                            position   : 'absolute',
                            zIndex     : '100',
                            top        : '0',
                            right      : '0',
                            left       : '0',
                            bottom     : '0',
                            background : 'rgba(0, 0, 0, 0.5)',
                            height     : '580px',
                            width      : '100%',
                        }}
                    />
                    <i
                        className="fa fa-spinner fa-spin fa-2x"
                        style={{
                            position  : 'absolute',
                            color     : '#fff ',
                            top       : '50px',
                            zIndex    : '101',
                            left      : '40%',
                            transform : 'translateX(-50%)',
                        }}
                    />
                </div>
            </h2>
        );
    }
    return (
        <div className="wrapCommande">
            <div className="wrapTitle">
                <h2>MA COMMANDE</h2>
            </div>
            <div className="commande">
                <div className="table">
                    <div className="row">
                        <div className="col-md-5 col-12 th">LOCATION</div>
                        <div className="col-md-3 col-5 th">
                                PRIX UNITAIRE TTC
                        </div>
                        <div className="col-md-2 col-3 th">QUANTITE</div>
                        <div className="col-md-1 col-3 th">PRIX TTC</div>
                        <div className="col-md-1 col-1 hidden-sm-up th" />
                    </div>
                    {cart.items.map((item, idx) => (
                        <div className="row" key={idx}>
                            <div className="col-md-5 col-12 td">
                                <div className="imageDetailWrapper">
                                    <div>
                                        <img
                                            src={item.id.imageUrl}
                                            alt={item.id.name}
                                        />
                                    </div>
                                    <div className="imageDetail">
                                        <span className="locationDetail">
                                                Location
                                        </span>
                                        <br />
                                            - {item.id.name}
                                        <br />
                                            - 10 min<br />
                                            - Circuit 330m
                                    </div>
                                </div>
                            </div>
                            <div className="col-md-3 col-5 td prices">
                                <p className={item.quantity >= 5 ? 'crossed' : ''}>
                                    {Number(item.id.price[taxDisplay].normal).aqlRound(2)} € <sub>{t(`common:price.${taxDisplay}`)}</sub>
                                </p>
                                {item.quantity >= 5 && (
                                    <p>
                                        {Number(item.id.price[taxDisplay].special).aqlRound(2)}
                                    </p>
                                )}
                            </div>
                            <div className="col-md-2 col-4 td">
                                <button
                                    className="btnLess"
                                    onClick={() => this.qtyModifier('-', idx)
                                    }
                                >
                                        -
                                </button>
                                <input
                                    id="qtyChoosenKart"
                                    type="number"
                                    value={item.quantity}
                                    onChange={input => this.onChangeQuantity(input, idx)
                                    }
                                    min="1"
                                />
                                <button
                                    className="btnMore"
                                    onClick={() => this.qtyModifier('+', idx)
                                    }
                                >
                                        +
                                </button>
                            </div>
                            <div className="col-md-1 col-3 td">
                                {this.calculTotalPrice(item)} €
                            </div>
                            <div className="col-md-1 col-0 td">
                                <button
                                    className="btnDelete"
                                    onClick={() => this.deleteProduct(idx)}
                                >
                                        x
                                </button>
                            </div>
                        </div>
                    ))}
                </div>
                <div className="recapPrice">
                    <div className="totalLabel">TOTAL</div>
                    <div className="totalPriceKart">
                        {cart.priceTotal.ati.aqlRound(2)} €
                    </div>
                </div>
                <div className="buttonsContinuerValider">
                    <button
                        id="continueAchat"
                        onClick={() => (window.location.pathname = '/adultes')
                        }
                    >
                            CONTINUER MES ACHATS
                    </button>
                    <button
                        id="validerCommande"
                        onClick={this.validateCart}
                    >
                            VALIDER MA COMMANDE
                    </button>
                </div>
            </div>
            <style jsx="true">{`
                    .wrapTitle {
                        justify-content: center;
                        display: flex;
                        margin-bottom: 70px;
                        margin-top: 20px;
                    }
                    h2 {
                        font-size: 20px;
                        color: rgb(253, 188, 88);
                    }
                    .table .row:nth-last-child {
                        padding-bottom: 10px;
                    }
                    .table img {
                        width: 140px;
                    }
                    .wrapCommande {
                        width: 100%;
                        justify-content: center;
                        display: flex;
                        flex-direction: column;
                    }
                    .commande {
                        justify-content: center;
                        flex-direction: column;
                        display: flex;
                        width: 100%;
                        margin: 0 auto;
                        max-width: 936px;
                    }
                    .recapPrice {
                        display: flex;
                        justify-content: flex-end;
                    }
                    .imageDetailWrapper {
                        justify-content: flex-start;
                        display: flex;
                    }
                    .imageDetail {
                        padding-left: 38px;
                    }
                    .locationDetail {
                        text-decoration: underline;
                    }
                    .totalLabel {
                        font-weight: bold;
                        padding: 2px 10px 2px 10px;
                    }
                    .totalPriceKart {
                        background: white;
                        color: black;
                        font-weight: bold;
                        font-size: 17px;
                        padding: 2px 10px 2px 10px;
                    }
                    .crossed {
                        text-decoration: line-through;
                    }
                    .th {
                        padding-bottom: 20px;
                    }
                    .row > .td {
                        vertical-align: top;
                        padding: 0;
                        padding-top: 20px;
                    }
                    .row:last-child .td {
                        padding-bottom: 20px;
                    }
                    .table,
                    .table .row:first-child {
                        border-bottom: 1px solid white;
                    }
                    input::-webkit-outer-spin-button,
                    input::-webkit-inner-spin-button {
                        -webkit-appearance: none;
                        margin: 0;
                    }
                    #qtyChoosen {
                        width: 22px;
                        height: 22px;
                        text-align: center;
                        font-size: 12px;
                        margin: 0px 5px 0px 5px;
                        border: 0;
                        vertical-align: bottom;
                        appearance: textfield;
                        color: white;
                        background: black;
                        border-left: 1px solid white;
                        border-bottom: 1px solid white;
                        border-right: 1px solid #4a4a4a;
                        border-top: 1px solid #4a4a4a;
                    }
                    .btnMore,
                    .btnLess {
                        width: 22px;
                        height: 22px;
                        background-color: #4a4a4a;
                        font-size: 14px;
                        color: white;
                        border: none;
                        cursor: pointer;
                        transition: all 0.2s;
                        position: relative;
                        vertical-align: middle;
                        line-height: 1px;
                    }
                    .btnDelete {
                        background: transparent;
                        border: 1px solid grey;
                        color: white;
                        border-radius: 100%;
                        height: 20px;
                        width: 20px;
                        cursor: pointer;
                        font-size: 13px;
                        line-height: 1px;
                        cursor: pointer;
                    }
                    .btnDeleteIcon .btnMore:hover,
                    .btnLess:hover {
                        text-decoration: none;
                        background-color: #4a4a4aa3;
                    }
                    .buttonsContinuerValider {
                        display: flex;
                        justify-content: space-between;
                        margin-top: 42px;
                        margin-bottom: 62px;
                    }
                    #continueAchat {
                        color: white;
                        background: #505050;
                        border: none;
                        font-size: 22px;
                        cursor: pointer;
                        text-align: center;
                        line-height: 35px;
                        transition: 0.4s;
                    }
                    #validerCommande {
                        color: white;
                        background: rgb(253, 188, 88);
                        font-size: 22px;
                        border: none;
                        cursor: pointer;
                        text-align: center;
                        line-height: 35px;
                        transition: 0.4s;
                    }
                    #continueAchat:hover {
                        background: #5f5f5f;
                    }
                    #validerCommande:hover {
                        background: rgb(247, 174, 63);
                    }
                    @media (max-width: 768px) {
                        .table {
                            padding: 0 15px;
                        }
                        .th {
                            display: none;
                        }
                        .table .prices p {
                            display: inline-block;
                            width: 50%;
                        }
                        .table .row {
                            border-top: 1px solid #fff;
                        }
                        .row .td.col-0 {
                            position: absolute;
                            top: 10px;
                            right: 10px;
                            width: 20px;
                            padding: 0;
                        }
                        .row {
                            position: relative;
                        }
                    }
                    ${this.cssHook};
                `}</style>
            {this.jsxHook}
        </div>
    );
}
}
