import React from 'react';
import axios from 'axios';
import {NSToast} from './NSToast';
import getAPIUrl from '../lib/generateAPIUrl';
import { isAuth } from '../lib/isAuth';

/**
 * @return {React.Component}
 */
export class NSCartBillingStep extends React.Component {
    constructor(props) {
        super(props);
        this.state = {
            client : {
                _id         : '',
                lastname    : '', // Required
                firstname   : '', // Required
                companyName : '', // Dans addresses
                zipcode     : '', // Dans addresses
                city        : '', // Dans addresses
                line1       : '', // Dans addresses
                line2       : '', // Dans addresses
                phone       : '',
            },
        };
        this.cssHook = '';
        this.jsxHook = undefined;
    }
    getClientInfos(client) {
        const {
            lastname, firstname, phone, addresses, _id,
        } = client;
        if (addresses.length != 0) {
            const {
                companyName, zipcode, city, line1, line2,
            } = addresses[0];
            client = {
                ...this.state.client,
                _id,
                lastname,
                firstname,
                phone,
                companyName,
                zipcode,
                city,
                line1,
                line2,
            };
        } else {
            client = {
                ...this.state.client,
                _id,
                lastname,
                firstname,
                phone,
            };
        }
        return client;
    }
    async componentDidMount() {
        // Un token jwt est de forme chars.chars.chars le "chars" du milieu correspond au payload (les datas de l'utilisateurs) encodés en base 64
        try {
            const { isLogged, client } = await isAuth(getAPIUrl());
            if (isLogged) {
                // On récupére uniquement les informations pertinentes pour l'utilisateur
                if (
                    !window.localStorage.getItem('cart_id') &&
                    this.props.fromCart
                ) { return (window.location.pathname = '/cart'); }
                const clientData = this.getClientInfos(client);
                this.setState({ client: clientData, email: client.email });
            } else {
                window.location.pathname = '/cart/login';
            }
        } catch (error) {
            console.error(error);
            window.location.pathname = '/cart/login';
        }
    }

    saveClient = async () => {
        try {
            const {
                _id,
                companyName,
                zipcode,
                city,
                line1,
                line2,
            } = this.state.client;
            const updatedUser = await axios.patch(`${getAPIUrl()}users`, {
                _id,
                info : this.state.client,
            });
            const updatedAddress = await axios.put(
                `${getAPIUrl()}v2/user/addresses/`,
                {
                    userId    : _id,
                    addresses : [
                        {
                            companyName,
                            zipcode,
                            city,
                            line1,
                            line2,
                        },
                    ],
                    delivery_address : 0,
                    billing_address  : 0,
                },
            );
        } catch (error) {
            console.error(error);
            NSToast.error("Impossible d'enregistrer les modifications, veuillez vous reconnecter !");
        }
    };
    handleBillingSubmit = async (e) => {
        try {
            e.preventDefault();
            if (!jwtManager.get()) throw 'vous devez vous reconnecter';
            const {
                companyName,
                zipcode,
                city,
                line1,
                line2,
                firstname,
                lastname,
            } = this.state.client;
            this.saveClient();
            // On check la validité du cart
            const result = await axios.post(`${getAPIUrl()}cart/validate`, {
                cartId : window.localStorage.getItem('cart_id'),
            });
            if (result.data.code !== 'VALID') {
                if (result.data.code === 'NOTFOUND_RECEIPT_METHOD') {
                    return NSToast.error('Veuillez indiquer votre mode de réception et valider celui-ci.');
                }
                return NSToast.error("Votre panier n'est pas valide. Veuillez vérifier les informations saisies");
            }
            const resultAddresses = await axios.put(
                `${getAPIUrl()}cart/addresses`,
                {
                    cartId    : window.localStorage.getItem('cart_id'),
                    addresses : {
                        delivery : {
                            firstname,
                            lastname,
                            companyName,
                            zipcode,
                            city,
                            line1,
                            line2,
                            country : 'France',
                        },
                    },
                },
            );
            return (window.location.pathname = '/cart/summary');
        } catch (error) {
            console.error(error);
            NSToast.error("Impossible d'enregistrer les modifications, veuillez vous reconnecter !");
        }
    };
    handleAccountSubmit = (e) => {
        try {
            e.preventDefault();
            if (!jwtManager.get()) throw 'vous devez vous reconnecter';
            this.saveClient();
            NSToast.success('Informations enregistrées !');
        } catch (error) {
            console.error(error);
            NSToast.error("Impossible d'enregistrer les modifications, veuillez vous reconnecter !");
        }
    };
    handleInputChange = (e) => {
        const client = {
            ...this.state.client,
            [e.target.name] : e.target.value,
        };
        this.setState({ client });
    };

    render() {
        const widthLabel = '85';
        const {
            lastname,
            firstname,
            companyName,
            zipcode,
            city,
            line1,
            line2,
            phone,
        } = this.state.client;
        return (
            <div>
                <h3>MES INFORMATIONS</h3>
                <form
                    action=""
                    onSubmit={e =>
                        (this.props.fromCart
                            ? this.handleBillingSubmit(e)
                            : this.handleAccountSubmit(e))
                    }
                >
                    <div>
                        <label className="email">Email</label>
                        <input
                            type="email"
                            disabled
                            className="email"
                            value={this.state.email}
                        />
                    </div>
                    <div>
                        <label htmlFor="lastname">
                            Nom<span className="requiredLabel">*</span>
                        </label>
                        <input
                            id="lastname"
                            type="text"
                            name="lastname"
                            value={lastname}
                            onChange={this.handleInputChange}
                            required
                        />
                    </div>
                    <div>
                        <label htmlFor="firstname">
                            Prénom<span className="requiredLabel">*</span>
                        </label>
                        <input
                            id="firstname"
                            type="text"
                            name="firstname"
                            value={firstname}
                            onChange={this.handleInputChange}
                            required
                        />
                    </div>
                    <div>
                        <label htmlFor="companyName">Société</label>
                        <input
                            id="companyName"
                            type="text"
                            name="companyName"
                            value={companyName || ''}
                            onChange={this.handleInputChange}
                        />
                    </div>
                    <div>
                        <label htmlFor="line1">
                            Adresse 1<span className="requiredLabel">*</span>
                        </label>
                        <input
                            id="line1"
                            type="text"
                            name="line1"
                            value={line1 || ''}
                            onChange={this.handleInputChange}
                            required
                        />
                    </div>
                    <div>
                        <label htmlFor="line2">Complément d'adresse</label>
                        <input
                            id="line2"
                            type="text"
                            name="line2"
                            value={line2 || ''}
                            onChange={this.handleInputChange}
                        />
                    </div>
                    <div>
                        <label htmlFor="city">
                            Ville<span className="requiredLabel">*</span>
                        </label>
                        <input
                            id="city"
                            type="text"
                            name="city"
                            value={city || ''}
                            onChange={this.handleInputChange}
                            required
                        />
                    </div>
                    <div>
                        <label htmlFor="zipcode">
                            Code postal<span className="requiredLabel">*</span>
                        </label>
                        <input
                            id="zipcode"
                            type="text"
                            name="zipcode"
                            value={zipcode || ''}
                            onChange={this.handleInputChange}
                            required
                        />
                    </div>
                    <div>
                        <label htmlFor="phone">
                            Téléphone<span className="requiredLabel">*</span>
                        </label>
                        <input
                            id="phone"
                            type="tel"
                            name="phone"
                            value={phone || ''}
                            onChange={this.handleInputChange}
                            required
                        />
                    </div>
                    <div className="requiredLabelInfos">
                        <span className="requiredLabel">
                            *Champs obligatoire
                        </span>
                    </div>
                    <div className="validateBtn">
                        <button type="submit">VALIDER</button>
                    </div>
                    {
                        // <div className="generalInfos">
                        //     <p>
                        //         les informations receuillies sur ce formulaire sont enregistrées dans un fichier informatisé.<br />
                        //         Elles sont conservées pour une période indéinie et sont destinées au traitement de votre commande.
                        //     </p>
                        // </div>
                    }
                </form>

                <style jsx="true">
                    {`
                        /** TODO a supprimer quand il sera possible d'importer des fichiers css */
                        h3 {
                            color: #fdbc58;
                        }
                        form {
                            margin-top: 75px;
                        }
                        .generalInfos {
                            width: 100%;
                            text-align: center;
                            display: flex;
                            justify-content: center;
                            max-width: 400px;
                            margin-top: 50px;
                        }
                        .generalInfos > p {
                            text-align: center;
                            font-size: 12px;
                            padding-left: 100px;
                        }
                        .validateBtn {
                            display: flex;
                            justify-content: center;
                        }
                        button {
                            color: white;
                            background: rgb(253, 188, 88);
                            font-size: 22px;
                            border: none;
                            cursor: pointer;
                            text-align: center;
                            line-height: 35px;
                            width: fit-content;
                            margin-top: 8px;
                            transition: 0.4s;
                            padding-right: 10px;
                            padding-left: 10px;
                            margin-left: ${widthLabel}px;
                        }
                        button:hover {
                            background: rgb(247, 174, 63);
                        }
                        .requiredLabelInfos {
                            text-align: end;
                            width: 391px;
                            display: block;
                            margin: 0 auto;
                        }
                        .email {
                            color: grey;
                        }
                        label {
                            width: ${widthLabel}px;
                            text-align: end;
                            margin-right: 20px;
                            vertical-align: middle;
                        }
                        .requiredLabel {
                            font-size: 13px;
                            color: #fdbc58;
                            letter-spacing: 0;
                            text-align: right;
                            line-height: 21px;
                        }
                        .requireField {
                            color: #fdbc58;
                        }
                        button {
                            color: white;
                            background: rgb(253, 188, 88);
                            font-size: 22px;
                            border: none;
                            cursor: pointer;
                            text-align: center;
                            line-height: 35px;
                            width: fit-content;
                            margin-top: 8px;
                            transition: 0.4s;
                        }
                        button:hover {
                            background: rgb(247, 174, 63);
                        }
                        input {
                            background: black;
                            border: 1px solid white;
                            width: 306px;
                            height: 40px;
                            margin-top: 8px;
                            margin-bottom: 8px;
                            color: white;
                            padding-left: 10px;
                        }

                        @media (max-width: 768px) {
                            label {
                                text-align: center;
                                margin: 0;
                            }
                            input {
                                width: 100%;
                            }
                        }
                        @media (max-width: 465px) {
                            .requiredLabelInfos {
                                width: 100%;
                            }
                        }
                        ${this.cssHook};
                    `}
                </style>
                {this.jsxHook}
            </div>
        );
    }
}
