import React from 'react';
import axios from 'axios';
import { NSToast } from './NSToast';
import getAPIUrl from '../lib/generateAPIUrl';
/**
 * @return {React.Component}
 */
export class NSCartPaymentStep extends React.Component {
    constructor(props, context) {
        super(props, context);
        this.state   = {
            paymentMethods : [],
            paymentForm    : null,
        };
        this.cssHook = '';
        this.jsxHook = undefined;
        this.promoInvalid = false;
    }

    async componentDidMount() {
        const paymentMethods = await axios.post(`${getAPIUrl()}v2/paymentMethods`, { lang: this.props.i18n.language, PostBody: { filter: { active: true }, structure: {details: 1}, limit: 100 } });
        this.setState({ paymentMethods: paymentMethods.data.datas });
    }

    handleSummarySubmit = async (paymentMethod, Router, lang = '', prefix = '') => {
        try {
            // L'utilisateur va être rediriger (voir dans le catch de cette fonction)
            if (this.promoInvalid) return;
            const langPrefix = prefix !== '' ? prefix : '';
            // On transforme le panier en commande
            const result = await axios.put(`${getAPIUrl()}v2/cart/to/order`, {
                cartId : window.localStorage.getItem('cart_id'),
                lang
            });
            if (result.data.code !== 'ORDER_CREATED') {
                NSToast.error('payment:error_create_order', this.props.i18n);
            }
            const saveTransaction = new CustomEvent('saveTransaction', { detail: result.data.data });
            window.dispatchEvent(saveTransaction);

            if (result.data.data.status !== 'PAYMENT_PENDING' && result.data.data.status !== 'CANCELED') {
                window.localStorage.removeItem('cart_id');
            }
            
            // Si la methode de paiement choisi est un paiement différé
            if (paymentMethod.isDeferred === true) {
                await axios.post(`${getAPIUrl()}v2/payment/order/${result.data.data.number}${langPrefix}`, { 
                    paymentMethod: paymentMethod.code, 
                    filterPayment: {$or: [{all_points_of_sale: true}, {points_of_sale: result.data.data.point_of_sale}]} });
                // On envoie le mail au client pour les paiements différées.
                // console.log('send mail');
                // await axios.get(`${getAPIUrl()}v2/mail/confirmation/client/${result.data.data._id}`);
            }

            window.localStorage.setItem('order', JSON.stringify(result.data.data));

            if (paymentMethod.isDeferred === true) {
                Router.pushRoute(`${langPrefix}/cart/success`);
            } else {
                const paymentForm = await axios.post(`${getAPIUrl()}${paymentMethod.code}/${result.data.data._id}`, {});
                this.setState({ paymentForm: paymentForm.data }, () => {
                    document.getElementById('payment_form').submit();
                });
            }
        } catch (error) {
            if (error.response.data.code === 'promo_code_promo_invalid') {
                const timeout = 3000;
                this.promoInvalid = true;
                NSToast.error(error.response.data.message);
                setTimeout(() => {
                    if (this.props.redirectError) return window.location.pathname = this.props.redirectError;
                    return Router.pushRoute('/cart');
                }, timeout);
            } else if (error.response.data.code) {
                NSToast.error(error.response.data.message);
            } else {
                NSToast.error('payment:error_order', this.props.i18n);
            }
        }
    };

    render() {
        const { paymentMethods, paymentForm } = this.state;
        const sortedArray = paymentMethods.sort((a, b) => a.sort - b.sort);
        const props = this.props;
        return (
            <div className={`ns-payment-list${props.div ? ` ${props.div}` : ''}`}>
                <link rel="stylesheet" href="/static/css/payment-list.css" />
                <ul className={props.ul}>
                    {
                        sortedArray ? sortedArray.map(paymentMethod => (
                            <li key={paymentMethod.code} className={props.li}>
                                <a className={props.a ? props.a : 'btn-payment-method'} onClick={() => this.handleSummarySubmit(paymentMethod)}>
                                    <img src={paymentMethod.urlLogo} alt={paymentMethod.code} className={props.img} />
                                    {' '}
                                    <span className={props.span}>
                                        {paymentMethod.description}
                                    </span>
                                </a>
                                <br />
                                <br />
                            </li>
                        )) : this.props.t('payment:no_method')
                    }
                </ul>
                <div className="content" dangerouslySetInnerHTML={{ __html: paymentForm }} hidden />
            </div>
        );
    }
}
