import React, { Component } from 'react';
import PropTypes from 'prop-types';
import axios from 'axios';
import getAPIUrl from '../lib/generateAPIUrl';


export class NSCartProductCounter extends Component {
    constructor(props, context) {
        super(props, context);
        this.state = {
            cart : {},
            show : true,
        };
    }

    async componentDidMount() {
        if (typeof window !== 'undefined' && window.localStorage.getItem('cart_id') !== null) {
            this.getCart();
        } else {
            this.setState({ cart: { items: [] } });
        }
        window.addEventListener('updateCart', this.getCart);
    }
    componentWillUnmount() {
        window.removeEventListener('updateCart', this.getCart);
    }
    getCart = async () => {
        try {
            const cartId = window.localStorage.getItem('cart_id');
            if (!cartId) return;
            const result = await axios.post(`${getAPIUrl()}v2/cart/${cartId}`);
            this.setState({ cart: result.data });
        } catch (e) {
            console.error(e);
            window.localStorage.removeItem('cart_id');
            this.setState({ cart: { items: [] } });
        }
    }

    render() {
        const { cart, show } = this.state;
        return (
            <li>
                {!cart.items ?
                    <a href="/cart">
                        <i className="ico-cart" />
                        <span className="nav__inner">
                            {this.props.t('common:monPanier')}
                            <small><i className="fa fa-spin fa-spinner" /></small>
                        </span>
                    </a> :
                    cart && cart._id && cart.items.length > 0
                        ? <a href="/cart">
                            <i className="ico-cart" />
                            <span className="nav__inner">
                                {this.props.t('common:monPanier')}
                                <small>{`${cart.items.length} ${cart.items.length > 1 ? this.props.t('common:itemsCart') : this.props.t('common:itemCart')}`}</small>
                            </span>
                        </a>
                        : <a href="/cart">
                            <i className="ico-cart" />
                            <span className="nav__inner">
                                {this.props.t('common:monPanier')}
                                <small>{this.props.t('common:noItemCart')}</small>
                            </span>
                        </a>
                }
            </li>
        );
    }
    static contextTypes = {
        getPageState : PropTypes.func,
        getCart      : PropTypes.func,
    };
}
