import React from 'react';
import axios from 'axios';
import {NSToast} from './NSToast';
import getAPIUrl from '../lib/generateAPIUrl';
import { isAuth } from '../lib/isAuth';
import jwtManager from '../lib/jwtManager';

/**
 * @return {React.Component}
 */
export class NSCartSummaryStep extends React.Component {
    constructor(props) {
        super(props);
        this.et_rate = 0.2;
        this.state = {
            cart       : null,
            client     : {},
            taxDisplay : 'ati'
        };
        this.cssHook = '';
        this.jsxHook = undefined;
    }

    handleSummarySubmit = async () => {
        if (this.checkbox.checked) {
            try {
                // On transforme le panier en commande
                const result = await axios.post(`${getAPIUrl()}cart/toOrder`, {
                    cartId : window.localStorage.getItem('cart_id'),
                });
                if (result.data.code !== 'ORDER_CREATED') {
                    NSToast.error('Une erreur est survenue lors de la création de la commande');
                }

                window.localStorage.setItem(
                    'order',
                    JSON.stringify(result.data.data),
                );
                // On redirige vers /cart/payment
                window.location.pathname = '/cart/payment';
            } catch (error) {
                console.error(error);
                NSToast.error('Une erreur est survenue lors de la commande');
            }
        } else {
            NSToast.error('Vous devez cocher les conditions générales de vente');
            console.error('Vous devez cocher les conditions générales de vente');
        }
    };

    async componentDidMount() {
        try {
            const { isLogged, client: clientAuth } = await isAuth(getAPIUrl());
            // si l'utilisateur n'est pas logué alors on redirige
            if (!isLogged) return (window.location.pathname = '/cart');
            const cartId = window.localStorage.getItem('cart_id');
            if (!cartId) return (window.location.pathname = '/cart');
            const result = await axios.get(`${getAPIUrl()}cart/${cartId}`);
            if (result.data.code != 'GET_CART_SUCCESS') throw result.data.code;
            const client = {
                firstname : clientAuth.firstname,
                lastname  : clientAuth.lastname,
                phone     : clientAuth.phone,
                addresses : `${clientAuth.addresses[0].line1} ${
                    clientAuth.addresses[0].line2
                }`,
                email : clientAuth.email,
            };
            const taxDisplay = jwtManager.getTaxDisplay();
            this.setState({
                cart : result.data.data.cart,
                client,
                taxDisplay
            });
        } catch (error) {
            console.error(error);
            return (window.location.pathname = '/cart');
        }
    }

    findAttributes(attributes) {
        for (let i = 0; i < attributes.length; i++) {
            if (attributes[i].code === 'type') return `/${attributes[i].value}`;
        }
    }

    handleCondition = () => (window.location.pathname = '/mentions-legales');

    render() {
        const { cart, client, taxDisplay } = this.state;
        if (!cart) return 'Chargement des données ...';
        return (
            <div className="wrapCommande">
                <article>
                    {' '}
                    {cart
                    && cart.items.map((item, i) => {
                        let type = 'none';
                        if (item.id.attributes) {
                            type = item.id.attributes.find(attr => attr.code === 'type').value;
                        }
                        const color =                                  type === 'adultes'
                            ? '#FDBC58'
                            : type === 'enfants'
                                ? '#4EBBDE'
                                : '#7EB620';
                        return (
                            <div className="productCard" key={i}>
                                <ProductCard
                                    cartdisplay
                                    productid={item.id._id}
                                    productAsPath={this.findAttributes(item.id.attributes)}
                                />{' '}
                                <div
                                    className="price-group"
                                    style={{
                                        width     : '100%',
                                        position  : 'relative',
                                        marginTop : '-100px',
                                    }}
                                >
                                    <p
                                        className="price"
                                        style={{
                                            position   : 'absolute',
                                            top        : '50%',
                                            transform  : 'translateY(-50%)',
                                            right      : '10px',
                                            color      : '#000',
                                            fontSize   : '25px',
                                            fontWeight : 'bold',
                                        }}
                                    >
                                        {item.quantity}
                                        x{' '}
                                        {(item.quantity >= 5
                                            ? item.id.price[taXdisplay].special
                                            : item.id.price[taxDisplay].normal || 0
                                        ).aqlRound(2)}€ <span> {t(`common:price.${taxDisplay}`)} </span>
                                    </p>
                                    <div
                                        dangerouslySetInnerHTML={{
                                            __html :
                                                '<svg width="255" height="70" viewBox="0 0 255 70" version="1.1" xmlns="http://www.w3.org/2000/svg"xmlns:xlink="http://www.w3.org/1999/xlink">                    <!-- Generator: Sketch 49.2 (51160) - http://www.bohemiancoding.com/sketch -->                    <desc>Created with Sketch.</desc>                    <defs></defs>                    <g id="LOCATION-ADULTES" stroke="none" stroke-width="1" fill="none" fill-rule="evenodd">                    <g id="LOCATIONS-ADULTES" transform="translate(-446.000000, -1442.000000)" fill="#9B9B9B">                    <g id="TARIFS" transform="translate(0.000000, 629.000000)">                    <polygon id="Rectangle-2-Copy-7" transform="translate(573.500000, 847.988281) scale(-1, -1) translate(-573.500000, -847.988281) " points="446 826.976562 701 813 701 869.822545 446 882.976562"></polygon>                    </g>                    </g>                    </g>                    </svg>',
                                        }}
                                    />{' '}
                                </div>{' '}
                                <div
                                    className="price-total"
                                    style={{
                                        width     : '100%',
                                        position  : 'relative',
                                        marginTop : '-20px',
                                    }}
                                >
                                    <p
                                        className="price"
                                        style={{
                                            position   : 'absolute',
                                            top        : '50%',
                                            transform  : 'translateY(-50%)',
                                            right      : '10px',
                                            color      : '#000',
                                            fontSize   : '25px',
                                            fontWeight : 'bold',
                                        }}
                                    >
                                        {(item.quantity >= 5
                                            ? item.id.price[taxDisplay].special
                                                * item.quantity
                                            : item.id.price[taxDisplay].normal
                                                * item.quantity || 0
                                        ).aqlRound(2)}€ <span> {t(`common:price.${taxDisplay}`)} </span>
                                    </p>
                                    <p
                                        className="price"
                                        style={{
                                            position   : 'absolute',
                                            top        : '60%',
                                            transform  : 'translateY(-50%)',
                                            left       : '10px',
                                            color      : '#000',
                                            fontSize   : '18px',
                                            fontWeight : 'bold',
                                        }}
                                    >
                                        TOTAL{' '}
                                    </p>{' '}
                                    <div
                                        dangerouslySetInnerHTML={{
                                            __html : `<svg width="255" height="70" viewBox="0 0 255 70" version="1.1" xmlns="http://www.w3.org/2000/svg"xmlns:xlink="http://www.w3.org/1999/xlink">                    <!-- Generator: Sketch 49.2 (51160) - http://www.bohemiancoding.com/sketch -->                    <desc>Created with Sketch.</desc>                    <defs></defs>                    <g id="LOCATION-ADULTES" stroke="none" stroke-width="1" fill="none" fill-rule="evenodd">                        <g id="LOCATIONS-ADULTES" transform="translate(-446.000000, -1284.000000)" fill="${color}">                            <g id="TARIFS" transform="translate(0.000000, 629.000000)">                                <polygon id="Rectangle-2-Copy-3" transform="translate(573.500000, 689.988281) scale(-1, -1) translate(-573.500000, -689.988281) " points="446 668.976562 701 655 701 711.822545 446 724.976562">test</polygon>                    </g>                        </g>                    </g> </svg>`,
                                        }}
                                    />{' '}
                                </div>{' '}
                            </div>
                        );
                    })}{' '}
                </article>{' '}
                <div className="recapPrix">
                    <div>
                        <div className="labelTVA"> TVA </div>{' '}
                        <div className="totalTVA">
                            {' '}
                            {(
                                cart.priceTotal.ati.aqlRound(2) * this.et_rate
                            ).aqlRound(2)}€{' '}
                        </div>{' '}
                    </div>{' '}
                    <div>
                        <div className="labelTotal"> TOTAL </div>{' '}
                        <div className="total">
                            {' '}
                            {cart.priceTotal.ati.aqlRound(2)}€{' '}
                        </div>{' '}
                    </div>{' '}
                </div>{' '}
                <div className="descriptioClient">
                    <p>
                        Nom: {client.lastname} <br />
                        Prénom: {client.firstname}{' '}
                    </p>{' '}
                    <p>
                        Adresse: {client.addresses} <br />
                        Téléphone: {client.phone}{' '}
                    </p>{' '}
                    <p> E - mail: {client.email} </p>{' '}
                </div>{' '}
                <div className="conditionVente">
                    <label htmlFor="checkbox">
                        <input
                            id="checkbox"
                            type="checkbox"
                            ref={input => (this.checkbox = input)}
                        />{' '}
                        j'accepte les conditions générales de vente{' '}
                        <a
                            className="voirCondition"
                            href="/mentions - legales "
                            target="_blank "
                        >
                            Voir les conditions
                        </a>{' '}
                    </label>{' '}
                </div>{' '}
                <div className="continueWrapper">
                    <button
                        className="continueBtn"
                        href="/"
                        onClick={this.handleSummarySubmit}
                    >
                        {' '}
                        CONTINUER{' '}
                    </button>{' '}
                </div>{' '}
                <style jsx="true">
                    {' '}
                    {`
                    .productCard .product-card{
                        height: 500px !important;
                    }
                `}{' '}
                </style>{' '}
                <style jsx="true">
                    {' '}
                    {`
                        .voirCondition {
                            cursor: pointer;
                        }
                        .productCard {
                            margin: 0px 10px 0px 10px;
                        }
                        .articleKart {
                            width: 255px;
                            height: 730px;
                            background: #969696;
                            margin: 15px;
                        }
                        article {
                            display: flex;
                            justify-content: center;
                        }
                        .recapPrix {
                            display: flex;
                            flex-direction: column;
                            max-width: 550px;
                            margin-top: 20px;
                        }
                        .recapPrix > div {
                            display: flex;
                            justify-content: flex-end;
                        }
                        .recapPrix > :first-child {
                            border-bottom: 1px solid #fdbc58;
                        }
                        .labelTVA {
                            text-align: end;
                        }
                        .labelTotal {
                            text-align: center;
                        }
                        .labelTotal,
                        .labelTVA {
                            font-size: 20px;
                            justify-content: center;
                            display: flex;
                            flex-direction: column;
                            margin-right: 13px;
                        }
                        .labelTotal {
                            font-weight: bold;
                        }
                        .totalTVA {
                            font-size: 22px;
                        }
                        .total,
                        .totalTVA {
                            width: 110px;
                            text-align: end;
                            padding: 0px 10px 0px 10px;
                        }
                        .total {
                            background: #fdbc58;
                            color: black;
                            font-weight: bold;
                            font-size: 27px;
                            text-align: center;
                        }

                        .descriptioClient,
                        .conditionVente {
                            font-size: 18px;
                        }
                        .conditionVente {
                            margin-top: 30px;
                            text-align: center;
                        }
                        .voirCondition {
                            color: #fdbc58;
                            text-decoration: underline;
                        }
                        .continueWrapper {
                            text-align: center;
                            margin-top: 50px;
                        }
                        .continueBtn {
                            color: white;
                            background: rgb(253, 188, 88);
                            font-size: 22px;
                            border: none;
                            cursor: pointer;
                            text-align: center;
                            line-height: 35px;
                        }
                        .continueBtn:hover {
                            background: rgb(247, 174, 63);
                        }

                        .custom-modal {
                            width: 300px;
                            height: 300px;
                        }
                        .custom-modal h3 {
                            font-family: Oswald, sans-serif;
                            text-align: center;
                        }
                        ${this.cssHook};
                    `}{' '}
                </style>
                {this.jsxHook}
            </div>
        );
    }
}
