import axios from 'axios';
import React from 'react';
import PropTypes from 'prop-types';
import {NSToast} from './NSToast';
import getAPIUrl from '../lib/generateAPIUrl';

export class NSCodePromo extends React.Component {
    static contextTypes = { getPageState: PropTypes.func };

    constructor(props, context) {
        super(props, context);
        this.state = {
            code       : '',
            errorPromo : null,
            cart_id    : null,
            promo      : null,
            lang       : 'fr',
        };
    }

    async componentDidMount() {
        try {
            let eventDiscountAdded;
            let state;
            // On verifie qu'on est bien connecté
            const cart_id = window.localStorage.getItem('cart_id');
            if (!cart_id) return;
            // On récupére le cart, si il possède un code promo alors on l'ajoute au state
            const result = await axios.post(`${getAPIUrl()}v2/cart/${cart_id}`, { lang: this.props.i18n.language, PostBody: { populate: ['items.id'] } });
            const promo = result.data.promos && result.data.promos.length ? result.data.promos[0] : null;
            if (promo === null) {
                eventDiscountAdded = new window.CustomEvent('discountAdded', { detail: { error: true } });
                state = { cart_id };
            } else {
                state = {
                    code : promo.code, promo, cart_id, lang : this.props.i18n.language,
                };
                eventDiscountAdded = new window.CustomEvent('discountAdded', { detail: { error: false } });
            }
            window.dispatchEvent(eventDiscountAdded);
            return this.setState(state);
        } catch (error) {
            console.error(error);
        }
    }

    handleChange = event =>  this.setState({ code: event.target.value });

    handleClick = async () => {
        let eventDiscountAdded;
        try {
            const { code, cart_id } = this.state;
            if (!cart_id) return NSToast.error('cart:page.code_promo.error.empty_cart', this.props.i18n);
            if (!code) return NSToast.error('cart:page.code_promo.error.empty_code', this.props.i18n);
            // Retourne le cart avec la promo si la promo est valide
            const result = await axios.get(`${getAPIUrl()}v2/promo/check/code/${code}/${cart_id}`);
            const promo = result.data.promos.length ? result.data.promos[0] : null;
            if (!promo) NSToast.error('cart:page.code_promo.error.unknown_code', this.props.i18n);
            this.setState({ code: promo.code, promo, errorPromo: null });
            // On crée un evenement qui sera envoyé, le panier écoutera sur cet evenement et mettra a jour le cart dans son state
            // result.data correspond au cart du client
            eventDiscountAdded = new window.CustomEvent('discountAdded', { detail: { error: false } });
            window.dispatchEvent(eventDiscountAdded);
            return NSToast.success('cart:page.code_promo.success.discount_added', this.props.i18n);
        } catch (error) {
            // Si une erreur arrive (que le code promo n'est pas bon), nous renvoyons l'event afin de réactualiser le panier
            eventDiscountAdded = new window.CustomEvent('discountAdded', { detail: { error: true } });
            window.dispatchEvent(eventDiscountAdded);
            this.setState({ promo: null, errorPromo: error });
            if (error.response && error.response.data && error.response.data.message) {
                return NSToast.error(error.response.data.message);
            }
        }
    }
    handleKeyPress = (e) => {
        if (e.key !== 'Enter') return;
        this.handleClick();
    }
    render() {
        const { promo, errorPromo } = this.state;
        let classColor;
        if (promo) classColor = 'promo__btn valid';
        else if (errorPromo) classColor = 'promo__error error';
        else classColor = 'promo__btn';
        return (
            <div className="promo">
                <div className="promo__controls">
                    <input type="text" name="promo" id="promo" className="promo__field" onChange={this.handleChange} onKeyPress={this.handleKeyPress} value={this.state.code} placeholder={this.props.t('cart:page.code_promo.placeholder')} />
                    <button type="button" className={classColor} onClick={this.handleClick} />
                </div> {/* <!-- /.promo__controls --> */}
                { promo && <div className="promo__controls">{promo.description}</div> }
                <style jsx>{`
                .codePromo {
                    font-size: 26px;
                    margin-left: 6px;
                }
                .promo { width: 254px; }

                .promo .promo__controls {
                    position: relative;
                }

                .promo .promo__field {
                    width: 100%;
                    height: 48px;
                    padding: 0 60px 0 21px;
                    border: 1px solid #979797;
                    border-radius: 8px;
                    background: transparent;
                    font-family: 'Lato',
                    sans-serif;
                    font-size: 18px;
                    font-weight: 300;
                    font-style: italic;
                    color: #253553;
                    -webkit-appearance: none;
                    -moz-appearance: none;
                    appearance: none;
                    -webkit-transition: .3s;
                    -o-transition: .3s;
                    transition: .3s;
                }

                .promo .promo__btn {
                    position: absolute;
                    top: 0; right: 0;
                    width: 54px;
                    height: 48px;
                    border: 0;
                    border-radius: 8px;
                    background: #2c414e;
                    -webkit-appearance: none;
                    -moz-appearance: none;
                    appearance: none;
                    -webkit-transition: .3s;
                    -o-transition: .3s;
                    transition: .3s;
                }
                .promo .promo__error {
                    position: absolute;
                    top: 0; right: 0;
                    width: 54px;
                    height: 48px;
                    border: 0;
                    border-radius: 8px;
                    background: #2c414e;
                    -webkit-appearance: none;
                    -moz-appearance: none;
                    appearance: none;
                    -webkit-transition: .3s;
                    -o-transition: .3s;
                    transition: .3s;
                }
                .promo .error {
                    background: #dc5d45;
                }
                .promo .valid{
                    background: #93c255;
                }
                .promo .promo__btn:before {
                    content: '';
                    position: absolute;
                    top: 4px;
                    right: 18px;
                    z-index: 1;
                    -webkit-transform: rotate(45deg);
                    -ms-transform: rotate(45deg);
                    transform: rotate(45deg);
                    width: 16px;
                    height: 32px;
                    border-width: 0 5px 5px 0;
                    border-style: solid;
                    border-color: #fff;
                }
                .promo .promo__error:before {
                    content: 'X';
                    color: white;
                    font-size: 28px;
                    font-weight: 700;
                    position: absolute;
                    top: 4px;
                    right: 18px;
                    z-index: 1;
                    -webkit-transform: rotate(45deg);
                    -ms-transform: rotate(45deg);
                    -webkit-transform: rotate(45deg);
                    -ms-transform: rotate(45deg);
                    transform: rotate(0deg);
                    width: 16px;
                }

            `}</style>
            </div>
        );
    }
}
