import React from 'react';
import axios from 'axios';
import PropTypes from 'prop-types';
import { NSToast } from './NSToast';
import jwtManager from '../lib/jwtManager';

/**
 * @return {React.Component}
 */
export class NSContact extends React.Component {
    static contextTypes = { getPageState: PropTypes.func };
    constructor(props) {
        super(props);
        this.myForm = React.createRef();
        this.state = {
            action : '/api/v2/mail/form',
            method : 'post',
        };
    }

    componentDidMount() {
        const tokenJwt = jwtManager.get();
        if (tokenJwt) {
            // On récupére le token jwt et on le décode afin de récupérer le mail de l'utilisateur
            const user = tokenJwt.split('.')[1];
            const oUser = JSON.parse(decodeURIComponent(escape(window.atob(user))));
            document.querySelector("input[type='email']").value = oUser.info.email;
        }
        const { action, method } = this.state;
        let form = this.myForm.current;
        // On check l'html afin de ne pas boucler indéfiniment
        do { form = form.parentNode; } while (form.tagName !== 'FORM'  && form.tagName !== 'HTML');
        const tTextArea = form.getElementsByTagName('textarea');
        Array.from(tTextArea).forEach((textarea) => {
            if (textarea.value === 'undefined') {
                textarea.innerHTML = '';
                textarea.value = '';
            }
        });
        form.action = action;
        form.method = method;
        form.onsubmit = this.submitParentForm;
        const url = new URL(window.location);
        // On itére sur les parametres passé dans l'url
        for (const [key, value] of url.searchParams.entries()) {
            // On verifie si la clé pair[0] existe dans le formulaire, si existe déjà alors on met la valeur dans ce champs
            const field = document.getElementsByName(key);
            if (!field.length) {
                // le champ name n'a pas été trouvé, nous le créons donc un input hidden
                const input = document.createElement('input');
                input.type = 'text';
                input.hidden = true;
                input.name = key;
                input.value = value;
                form.appendChild(input);
            } else {
                // Si c'est un champ radio ou checkbox nous ne faisons rien car il ne faut pas modifier leur value
                if (['radio', 'checkbox'].includes(field[0].type)) {
                    // pour radio et checkbox la valeur correspond a l'id à cocher
                    document.getElementById(value).checked = true;
                    continue;
                }
                field[0].value = value;
            }
        }
    }

    submitParentForm = async (event) => {
        try {
            event.preventDefault();
            const formElements = event.target.elements;
            const formData = {};
            Object.keys(formElements).forEach((key) => {
                if (formElements[key].name) {
                    formData[formElements[key].name] = formElements[key].type === 'checkbox' || formElements[key].type === 'radio' ?
                        formElements[key].checked :
                        formElements[key].value;
                }
            });
            await axios.post(this.state.action, formData);
            event.target.reset();
            NSToast.success('common:contact.success.sendMessageSuccess', this.props.i18n);
        } catch (error) {
            console.log(error);
            if (error.response && error.response.data && error.response.data.status >= 400) {
                NSToast.error(error.response.data.message);
            } else {
                NSToast.error('cart:error.serverError', this.props.i18n);
            }
        }
    }

    render() {
        const buttonTitle = this.props['button-title'] || 'Envoyer';
        const captchaKey = this.props['captcha-key'] || null;
        return (
            <div className="formLine" ref={this.myForm}>
                <link rel="stylesheet" href="/static/css/contact.css" />
                <input type="submit" className="submitBtn" id="contact_submit" value={buttonTitle} />
                {
                    captchaKey && <div className="wrapperRecaptcha">
                        <div className="g-recaptcha" data-sitekey={captchaKey} />
                    </div>
                }
            </div>
        );
    }
}
