import React from 'react';
import axios from 'axios';
import getAPIUrl from '../lib/generateAPIUrl';

export function getCookie(cname) {
    const name = `${cname}=`;
    const ca = document.cookie.split(';');
    for (let i = 0; i < ca.length; i++) {
        let c = ca[i];
        while (c.charAt(0) === ' ') {
            c = c.substring(1);
        }
        if (c.indexOf(name) === 0) {
            return c.substring(name.length, c.length);
        }
    }
    return '';
}

export class NSCookieBanner extends React.Component {

    static defaultProps = {
        message: 'No message passed, add it on cookie-banner props',
        ['button-accept-text']: 'Accepter',
        ['button-deny-text']: 'Refuser',
        style: {}
    }

    constructor(props) {
        super(props);
        this.state = {
            hide              : true,
            message           : props.message,
            buttonAcceptText  : props['button-accept-text'],
            buttonDenyText    : props['button-deny-text'],
            style             : props.style
        };
    }

    componentDidMount = () => {
        this.setState({ hide: (['true', 'deny']).includes(getCookie('cookie_notice')) });
    }

    allow = async () => {
        await axios.post(`${getAPIUrl()}cookienotice`, {value: 'true'});
        this.setState({ hide: true }, () => window.location.reload());
    };

    deny = async () => {
        await axios.post(`${getAPIUrl()}cookienotice`, {value: 'deny'});
        this.setState({ hide: true });
    };

    render() {
        const {
            hide, message, buttonAcceptText, buttonDenyText, style
        } = this.state;
        if (!hide) {
            return (
                <div style={style} className="cookie-banner">
                    <link rel="stylesheet" href="/static/css/cookie-banner.css" />
                    <p className="cookie-message" dangerouslySetInnerHTML={{ __html: message }} />
                    <div className="cookie-buttons">
                        <button type="button" className="cookie-button" onClick={() => this.allow()}>
                            {buttonAcceptText}
                        </button>
                        <button type="button" className="cookie-button" onClick={() => this.deny()}>
                            {buttonDenyText}
                        </button>
                    </div>
                </div>
            );
        }
        return '';
    }
}