import React from 'react';
import PropTypes from 'prop-types';

/**
 * Fonction permettant de dessiner les étoiles (correspondant a la note global du produit ou du commentaire)
 */
export class NSDrawStars extends React.Component {
    constructor(props) {
        super(props);
        const note = Math.round(props.average.aqlRound(1));
        this.state = {
            note,
            tmpNote : 0 // Note sur onMouseEnter
        };
    }
    componentDidUpdate(prevProps) {
        if (this.props.average === prevProps.average) return;
        const note = Math.round(this.props.average.aqlRound(1));
        this.setState({note});
    }
    mouseEnter(e) {
        this.setState({tmpNote: Number(e.target.id) + 1});
    }
    mouseOut() {
        this.setState({tmpNote: this.state.note || 0});
    }
    render() {
        const {
            size, src, editmode, idQuestion, onClickStar
        } = this.props;
        const {note, tmpNote} = this.state;
        const list = [];
        if (editmode && idQuestion) {
            for (let i = 0; i < 5; i++) {
                if (i <= tmpNote - 1) {
                    list.push(<li key={i} id={i} className="liStarEdit" style={{cursor: 'pointer'}}>
                        <img width={size} id={i} height={size} src={src} alt="note" onMouseEnter={e => this.mouseEnter(e)} onClick={e => onClickStar({idQuestion, note: (Number(e.target.id) + 1)})} />
                              </li>);
                } else {
                    list.push(<li key={i} id={i} className="liStarEdit">
                        <img width={size} id={i} height={size} src={src} alt="note" onMouseEnter={e => this.mouseEnter(e)} style={{filter: 'grayscale(100%)'}} onClick={e => onClickStar(e)} />
                              </li>);
                }
            }
        } else {
            for (let i = 0; i < 5; i++) {
                if (i <= note - 1) {
                    list.push(<li key={i} id={i} className="liStar">
                        <img width={size} height={size} src={src} alt="note" />
                              </li>);
                } else {
                    list.push(<li key={i} id={i} className="liStar">
                        <img width={size} height={size} src={src} alt="note" style={{filter: 'grayscale(100%)'}} />
                              </li>);
                }
            }
        }
        return (<ul onMouseOut={e => this.mouseOut(e)} style={{display: 'flex', listStyle: 'none'}} >{list}</ul>);
    }

    static propTypes = {
        average     : PropTypes.number,
        size        : PropTypes.string,
        src         : PropTypes.string,
        editmode    : PropTypes.bool,
        onClickStar : PropTypes.func,
        idQuestion  : PropTypes.string
    };

    // En mode editmode = true: passer en parametre onClickStar, idQuestion, editmode
    static defaultProps = {
        average     : 0,
        size        : '14',
        src         : '',
        editmode    : false,
        onClickStar : null,
        idQuestion  : null
    };
}