import React, { Component } from 'react';
import PropTypes from 'prop-types';
import Slider from 'rc-slider';
import { shadeColor } from '../lib/helpers';

const createSliderWithTooltip = Slider.createSliderWithTooltip;
const Range                   = createSliderWithTooltip(Slider.Range);

export class NSFilters extends Component {
    constructor(props, context) {
        super(props, context);
        this.state = {
            taxDisplay   : context.getPageState().taxDisplay,
            filtersData  : context.getPageState().filtersData,
            min          : context ? context.getPageState().min : 0,
            max          : context ? context.getPageState().max : 0,
            langs        : context ? context.getPageState().langs : [],
            lang         : context ? context.getPageState().lang : 'en',
            filters      : context ? context.getPageState().filters : {},
            checkedArray : [],
            location     : '',
            ageValue     : { currMin: 0, currMax: 16 },
        };
    }

    static contextTypes = { getPageState: PropTypes.func };


    componentWillReceiveProps(props) {
        const obj = window.localStorage.getItem('filters') ? JSON.parse(window.localStorage.getItem('filters')) : {};
        if (props.location !== this.state.location) {
            this.setState({
                filters      : obj.category === props.location ? obj.filters : this.context.getPageState().filters,
                checkedArray : obj.category === props.location ? obj.checkedArray : [],
                ageValue     : obj.category === props.location && obj.ageValue ? { currMin: obj.ageValue.currMin, currMax: obj.ageValue.currMax } : { currMin: 0, currMax: 16 },
            });
        }
        if (props.location !== 'search') {
            this.setState({
                ...props,
                filtersData  : this.context.getPageState().filtersData,
                lang         : this.context.getPageState().lang,
                filters      : obj.category === props.location ? obj.filters : this.context.getPageState().filters,
                checkedArray : obj.category === props.location ? obj.checkedArray : [],
                ageValue     : obj.category === props.location && obj.ageValue ? { currMin: obj.ageValue.currMin, currMax: obj.ageValue.currMax } : { currMin: 0, currMax: 16 },
            });
        }
    }

    UNSAFE_componentWillMount() {
        if (
            this.context
            && this.context.getPageState()
            && typeof window !== 'undefined'
        ) {
            const obj = window.localStorage.getItem('filters') && JSON.parse(window.localStorage.getItem('filters')).category === this.props.location ? JSON.parse(window.localStorage.getItem('filters')) : {};
            const page = window.localStorage.getItem('page') && JSON.parse(window.localStorage.getItem('page')).location === this.props.location ? JSON.parse(window.localStorage.getItem('page')).page : 1;
            this.setState({
                filtersData  : this.context.getPageState().filtersData,
                lang         : this.context.getPageState().lang,
                min          : this.context.getPageState().min,
                max          : this.context.getPageState().max,
                filters      : obj.category === this.props.location ? obj.filters : this.context.getPageState().filters,
                checkedArray : obj.category === this.props.location ? obj.checkedArray : [],
                ageValue     : obj.category === this.props.location && obj.ageValue ? { currMin: obj.ageValue.currMin, currMax: obj.ageValue.currMax } : { currMin: 0, currMax: 16 },
                current      : page,
            }, () => {
                this.props.location === 'search'
                    ? this.props.reload(page, obj.category === this.props.location ? obj.filters : this.context.getPageState().filters) : this.props.reload(page, this.props.itemspp, undefined, obj.category === this.props.location && this.props.location !== 'search' ? obj.filters : this.context.getPageState().filters);
            });
        }
    }

    /**
     * Fonction permettant de réinitialiser les filtres
     * @param {*} keyLocalStorage clé du localStorage a supprimer contenant les informations du filter
     * @returns {void}
     */
    resetFilters(keyLocalStorage) {
        window.localStorage.removeItem(keyLocalStorage);
        window.location.reload();
    }

    onChange = (e, isNumber = undefined, checked = undefined, elemt = undefined) => {
        const { filters, taxDisplay, lang } = this.state;
        if (e.target.name === `price.${taxDisplay}.normal` && !checked) {
            filters.$and[0].$or[0][`price.${taxDisplay}.normal`] = { $gte: e.target.value[0], $lte: e.target.value[1] };
            filters.$and[0].$or[1][`price.${taxDisplay}.special`] = { $gte: e.target.value[0], $lte: e.target.value[1] };
        } else if ((e.target.type === 'Intervalle') && filters.$and.find(el => el && el.attributes && el.attributes.$elemMatch && el.attributes.$elemMatch.code === e.target.name)) {
            if (e.target.value[0] === e.target.min && e.target.value[1] === e.target.max) {
                const idx = filters.$and.findIndex(el => el && el.attributes && el.attributes.$elemMatch.code === e.target.name);
                delete filters.$and[idx];
            } else {
                const idx = filters.$and.findIndex(el => el && el.attributes && el.attributes.$elemMatch.code === e.target.name);
                filters.$and[idx].attributes.$elemMatch[`translation.${this.props.i18n.language}.value`] = { $gte: e.target.value[0], $lte: e.target.value[1] };
            }
        } else if (e.target.type === 'Intervalle' && (e.target.min !== e.target.value[0] || e.target.max !== e.target.value[1])) {
            filters.$and.push({
                attributes : {
                    $elemMatch : {
                        [`translation.${lang}.value`] : { $gte: e.target.value[0], $lte: e.target.value[1] },
                        code                          : e.target.name,
                    },
                },
            });
        } else if (checked === false) {
            const arr = this.state.checkedArray;
            arr.push(elemt);
            // Ajout d'un element au filtre
            const element = filters.$and.find(elem => elem.attributes && elem.attributes.$elemMatch.id === e.target.name);
            const index   = filters.$and.findIndex(elem => elem.attributes && elem.attributes.$elemMatch.id === e.target.name);
            if (index > -1 && element !== undefined && element.attributes.$elemMatch[`translation.${lang}.value`].$in.length !== undefined) {
                filters.$and[index].attributes.$elemMatch[`translation.${lang}.value`].$in.push(isNumber ? parseInt(e.target.value, 10) : e.target.value.toString());
            } else {
                filters.$and.push({
                    attributes : {
                        $elemMatch : {
                            [`translation.${lang}.value`] : { $in: [isNumber ? parseInt(e.target.value, 10) : e.target.value.toString()] },
                            id                            : e.target.name,
                        },
                    },
                });
            }
            this.setState({ filters, checkedArray: arr });
        } else {
            // Suppression d'un element du filtre
            const index = filters.$and.findIndex(elem => elem && elem.attributes && elem.attributes.$elemMatch.id === e.target.name);
            if (filters.$and[index]) {
                filters.$and[index].attributes.$elemMatch[`translation.${lang}.value`].$in.splice(filters.$and[index].attributes.$elemMatch[`translation.${lang}.value`].$in.findIndex(elem => parseInt(elem, 10) === e.target.value || elem.toString() === e.target.value), 1);
                if (filters.$and[index].attributes.$elemMatch[`translation.${lang}.value`].$in.length === 0 && index > -1) {
                    delete filters.$and.splice(index, 1);
                }
                const arr = this.state.checkedArray;
                arr.splice(arr.findIndex(el => el === elemt), 1);
                this.setState({ filters, checkedArray: arr });
            }
        }
        if (this.props.location !== 'search') {
            this.props.reload(1, this.props.itemspp, undefined, filters);
        } else {
            this.props.reload(1, filters);
        }
    };

    onChangePictos = (e, checked = undefined, elemt = undefined) => {
        const { filters, checkedArray, ageValue } = this.state;
        if (!checked) {
            checkedArray.push(elemt);
            // Ajout d'un element au filtre
            const element = filters.$and.find(elem => elem.pictos && elem.pictos.$elemMatch.code === e.target.name);
            const index   = filters.$and.findIndex(elem => elem.pictos && elem.pictos.$elemMatch.code === e.target.name);
            if (index > -1 && element !== undefined) {
                filters.$and[index].pictos.$elemMatch.code.$in.push(e.target.value.toString());
            } else {
                filters.$and.push({
                    pictos : {
                        $elemMatch : {
                            code : { $in: [e.target.value.toString()] },
                        },
                    },
                });
            }
            window.localStorage.setItem('filters', JSON.stringify({
                category : this.props.location, filters, checkedArray, ageValue,
            }));
            this.setState({ filters, checkedArray });
        } else {
            // Suppression d'un element du filtre
            const index = filters.$and.findIndex(elem => elem.pictos && elem.pictos.$elemMatch.code.$in.find(et => et === e.target.name));
            filters.$and[index].pictos.$elemMatch.code.$in.splice(filters.$and[index].pictos.$elemMatch.code.$in.findIndex(elem => elem.toString() === e.target.value), 1);
            if (filters.$and[index].pictos.$elemMatch.code.$in.length === 0 && index > -1) {
                delete filters.$and.splice(index, 1);
            }
            checkedArray.splice(checkedArray.findIndex(el => el === elemt), 1);
            window.localStorage.setItem('filters', JSON.stringify({
                category : this.props.location, filters, checkedArray, ageValue,
            }));
            this.setState({ filters, checkedArray });
        }
        if (this.props.location !== 'search') {
            this.props.reload(1, this.props.itemspp, undefined, filters);
        } else {
            this.props.reload(1, filters);
        }
    };

    onChangeValue = (e) => {
        const { filters, taxDisplay } = this.state;
        if (e.target.name === `price.${taxDisplay}.normal`) {
            filters.$and[0].$or[0][`price.${taxDisplay}.normal`] = { $gte: e.target.value[0], $lte: e.target.value[1] };
            filters.$and[0].$or[1][`price.${taxDisplay}.special`] = { $gte: e.target.value[0], $lte: e.target.value[1] };
        } else if (e.target.type === 'Intervalle' && filters.$and.find(el => el && el.attributes && el.attributes.$elemMatch.code === e.target.name)) {
            if (e.target.value[0] === e.target.min && e.target.value[1] === e.target.max) {
                const idx = filters.$and.findIndex(el => el && el.attributes && el.attributes.$elemMatch.code === e.target.name);
                filters.$and.splice(idx, 1);
            } else {
                const idx = filters.$and.findIndex(el => el && el.attributes && el.attributes.$elemMatch.code === e.target.name);
                filters.$and[idx].attributes.$elemMatch[`translation.${this.props.i18n.language}.value`] = { $gte: e.target.value[0], $lte: e.target.value[1] };
            }
        } else if (e.target.type === 'Intervalle' && (e.target.min !== e.target.value[0] || e.target.max !== e.target.value[1])) {
            filters.$and.push({
                attributes : {
                    $elemMatch : {
                        [`translation.${this.props.i18n.language}.value`] : { $gte: e.target.value[0], $lte: e.target.value[1] },
                        code                                              : e.target.name,
                    },
                },
            });
        }
        this.setState({ filters });
    };

    render() {
        const {
            filtersData, min, max, lang, filters, taxDisplay
        } = this.state;
        const { color, icons } = this.props;
        return (

            <form className="ns-filters">
                <link rel="stylesheet" href="/static/css/filters.css" />
                <div className="filters">
                    {
                        filtersData.attributes ? filtersData.attributes.map(filter => (
                            <div key={`${filter.id_attribut}`} className="filter">
                                <header className="filter-head">
                                    <h6 className="filter-title">
                                        {icons && icons.find(i => i.code === filter.code)
                                            ? (
                                                <img
                                                    src={icons.find(i => i.code === filter.code).img || ''}
                                                    alt={icons.find(i => i.code === filter.code).img || ''}
                                                    className="filterColor"
                                                />
                                            ) : ''}


                                        &nbsp;&nbsp;{filter.translation[lang].name}
                                    </h6>
                                </header>

                                <div className="filter-body">
                                    <div className="filter-values">
                                        {
                                            filtersData.attributesValues && filtersData.attributesValues[filter.id_attribut] ? filtersData.attributesValues[filter.id_attribut].map(f => (<div
                                                key={`${filter.id_attribut}_${f.display.toString().replace(/\s/g, '')}`}
                                                className="filter-value"
                                            >
                                                <button
                                                    type="button"
                                                    className={`filter-button ${this.state.checkedArray.includes(`${filter.id_attribut}_${f.display.toString().replace(/\s/g, '')}`) ? 'selected' : ''}`}
                                                >
                                                    <label
                                                        className="filters-label"
                                                        htmlFor={`${filter.id_attribut}_${f.display.toString().replace(/\s/g, '')}`}
                                                    >

                                                        <span className="filter-inside-value">
                                                            {f.display}
                                                            <input
                                                                id={`${filter.id_attribut}_${f.display.toString().replace(/\s/g, '')}`}
                                                                key={`${filter.id_attribut}_${f.display.toString().replace(/\s/g, '')}`}
                                                                type="checkbox"
                                                                style={{ display: 'none' }}
                                                                value={f.value}
                                                                name={filter.id_attribut}
                                                                onClick={e => this.onChange(e, typeof f.value === 'number', this.state.checkedArray.includes(`${filter.id_attribut}_${f.display.toString().replace(/\s/g, '')}`), `${filter.id_attribut}_${f.display.toString().replace(/\s/g, '')}`)}
                                                            />
                                                        </span>
                                                    </label>
                                                </button>
                                            </div>
                                            )) : ''
                                        }
                                    </div>
                                </div>
                            </div>
                        )) : ''
                    }
                    <div className="filter">
                        <header className="filter-head">
                            <h6 className="filter-title">
                                {icons && icons.find(i => i.code === 'prix')
                                    ? (
                                        <img
                                            src={icons.find(i => i.code === 'prix').img || ''}
                                            alt={icons.find(i => i.code === 'prix').img || ''}
                                            className="filterColor"
                                        />
                                    ) : ''}


                                &nbsp;&nbsp;Prix
                            </h6>
                        </header>

                        <div className="filter-body">
                            <Range
                                handleStyle={[{ borderColor: shadeColor('#000', 0.5) }]}
                                trackStyle={[{ backgroundColor: color || '#000' }]}
                                onChange={data => this.onChangeValue({ target: { name: `price.${taxDisplay}.normal`, value: data } })}
                                onAfterChange={data => this.onChange({ target: { name: `price.${taxDisplay}.normal`, value: data } })}
                                min={parseInt(min, 0)} max={parseInt(max, 0)}
                                tipFormatter={value => `${value} €`}
                                defaultValue={[parseInt(min, 0), parseInt(max, 0)]}
                                value={[parseInt(filters.$and[0].$or[0][`price.${taxDisplay}.normal`].$gte, 0), parseInt(filters.$and[0].$or[0][`price.${taxDisplay}.normal`].$lte, 0)]}
                            />


                            Entre&nbsp;
                            {parseInt(filters.$and[0].$or[0][`price.${taxDisplay}.normal`].$gte, 0)} € <sub>{t(`common:price.${taxDisplay}`)}</sub>
                            {parseInt(filters.$and[0].$or[0][`price.${taxDisplay}.normal`].$lte, 0)} € <sub>{t(`common:price.${taxDisplay}`)}</sub>
                        </div>
                    </div>
                    <div className="filter">
                        {/* <header className="filter-head"> */}
                        {/* <h6 className="filter-title"> */}
                        {/* {icons && icons.find(i => i.code === 'picto') */}
                        {/* ? ( */}
                        {/* <img */}
                        {/* src={icons.find(i => i.code === 'picto').img || ''} */}
                        {/* alt={icons.find(i => i.code === 'picto').img || ''} */}
                        {/* className="filterColor" */}
                        {/* /> */}
                        {/* ) : ''} */}


                        {/* &nbsp;&nbsp; */}
                        {/* Filtrer par */}
                        {/* </h6> */}
                        {/* </header> */}

                        <div className="filter-body">
                            <div className="filter-values">
                                {
                                    filtersData.pictos ? filtersData.pictos.map(f => (<div
                                        key={`${f.code.toString().replace(/\s/g, '')}`}
                                        className="filter-value"
                                    >
                                        <button
                                            type="button"
                                            className={`filter-button ${this.state.checkedArray.includes(`${f.code.toString().replace(/\s/g, '')}`) ? 'selected' : ''}`}
                                        >
                                            <label
                                                className="filters-label"
                                                htmlFor={`${f.code.toString().replace(/\s/g, '')}`}
                                            >

                                                <span className="filter-inside-value-picto">
                                                    {f.url ? (
                                                        <img
                                                            src={f.url}
                                                            alt={f.title}
                                                            title={f.title}
                                                            width={f.location === 'TOP_RIGHT' ? '70' : '15'}
                                                        />
                                                    ) : ''}
                                                    {' '}
                                                    <span style={{ verticalAlign: 'middle' }}>
                                                        {f.title}
                                                    </span>

                                                    <input
                                                        id={`${f.code.toString().replace(/\s/g, '')}`}
                                                        key={`${f.code.toString().replace(/\s/g, '')}`}
                                                        type="checkbox"
                                                        style={{ display: 'none' }}
                                                        value={f.code}
                                                        name={f.code}
                                                        onClick={e => this.onChangePictos(e, this.state.checkedArray.includes(`${f.code.toString().replace(/\s/g, '')}`), `${f.code.toString().replace(/\s/g, '')}`)}
                                                    />
                                                </span>
                                            </label>
                                        </button>
                                    </div>
                                    )) : ''
                                }
                            </div>
                        </div>
                    </div>
                </div>
                <style jsx="true">
                    {`
                        .filter-button.selected { background: ${color || '#000'}; border-color: ${color || '#000'}; color: #fff; }
                        .filter + .filter:before { background: ${color || '#000'}!important; }
                        .filterColor { background: ${color || '#000'}!important; }
                        @media screen and (min-width: 1024px) {
                            .filter-button:hover { background: ${color || '#000'}; border-color: ${color || '#000'}; color: #fff; }
                        }
                    `}
                </style>
            </form>
        );
    }
}
