import React from 'react';
import axios from 'axios';
import PropTypes from 'prop-types';
import getAPIUrl from '../lib/generateAPIUrl';

/**
 *  Video - Classe utilisée par le composant NSGallery
 * @prop content: (string) url de la video YouTube (https://www.youtube.com/embed/{content})
 * @return {React.Component}
 */
const Video = (props, context) => (
    <iframe
        width="560"
        height="315"
        src={`https://www.youtube.com/embed/${props.content}`}
        style={{
            maxWidth  : '100%',
            position  : 'absolute',
            left      : 0,
            right     : 0,
            margin    : 'auto',
            top       : '50%',
            transform : 'translateY(-50%)',
        }}
        title={props.content}
    />
);

/**
 * NSGallery - Charge les infoamrtion et les images de la galerie, catte gallery gere les images ainsi que les videos YouTube
 * @prop ns-code: (string) code de la gallery dans Aquila
 * @return {React.Component}
 */
export class NSGallery extends React.Component {
    constructor(props) {
        super(props);
        this.state = {
            photoIndex : 0,
            isOpen     : false,
            nsGallery  : null,
            btnActif   : true,
        };
        this.cssHook = '';
        this.jsxHook = undefined;
    }

    static contextTypes = { getPageState: PropTypes.func };

    componentDidMount = () => {
        window.addEventListener('popstate', (e) => {
            this.setState({ isOpen: false }, () => (window.location.pathname = e.state.as));
        });
    };

    openLightBox(i) {
        this.setState({ photoIndex: i, isOpen: true });
    }

    loadData = async () => {
        try {
            const code = this.props['ns-code'];
            const galleryItems = await axios.get(`${getAPIUrl()}v2/gallery/${code}/items`);
            this.setState({ nsGallery: galleryItems.data, btnActif: false });
        } catch (error) {
            console.error(error);
        }
    };
}
