import React from 'react';
import axios from 'axios';
import PropTypes from 'prop-types';
import getAPIUrl from '../lib/generateAPIUrl';

/**
 * NSMenu - Charge le menu corespondant au code passé en prop (ns-code)
 * @prop ns-code: (string) nom du menu à afficher
 * @return {React.Component}
 */
export class NSMenu extends React.Component {
    constructor(props) {
        super(props);
        this.state = {
            ...props,
            currentUrl : '',
            menuOpen   : false,
        };
        this.cssHook = '';
        this.jsxHook = undefined;
    }

    static contextTypes = { getPageState: PropTypes.func };

    componentDidMount() {
        this.setState({
            currentUrl :
                typeof window !== 'undefined' ? window.location.pathname : `/${this.getPageState().url.query._slug ? this.getPageState().url.query._slug : ''}`,
        });
    }

    componentWillReceiveProps(nextProp) {
        if (nextProp['ns-code'] == this.props['ns-code']) return;
        this.setState({
            content    : this.state.content,
            currentUrl :
                typeof window !== 'undefined' ? window.location.pathname : '',
        });
    }

    toggleMenu(e) {
        if (
            this.state.menuOpen &&
            document.querySelector('body').offsetWidth < 901
        ) {
            document.querySelector('.menu').style.height = '70px';
            document.querySelector('.div-menu').style.height = '70px';
            document.querySelector('header .content').style.height = '70px';
            document.querySelector('header').style.height = '70px';
        } else if (document.querySelector('body').offsetWidth < 901) {
            document.querySelector('.menu').style.height = '360px';
            document.querySelector('.div-menu').style.height = '360px';
            document.querySelector('header .content').style.height = '360px';
            document.querySelector('header').style.height = '360px';
        }
        this.setState({ menuOpen: !this.state.menuOpen });
    }

    updateComp(url) {
        this.setState({ currentUrl: url });
    }

    render() {
        const code = this.props['ns-code'];
        const menu = this.context.getPageState()[`nsMenu_${code}`];
        if (!menu) {
            return (
                <div>
                    Impossible d&apos;afficher le composant Menu, veuillez
                    verifier son ns-code
                </div>
            );
        }
        return (
            <div className="menu" style={{ position: 'relative' }}>
                <i
                    className="fa fa-bars fa-2x menu-toggle"
                    onClick={e => this.toggleMenu(e)}
                />
                {/* <Head><link href="/static/css/menu.css" rel="stylesheet" /></Head> */}
                <link href="/static/css/menu.css" rel="stylesheet" />
                <ul style={{ position: 'relative' }}>
                    <li onClick={() => this.toggleMenu()}>
                        <a href="/">
                            <img
                                src="/medias/racing-flag jaune.png"
                                alt="run_flag"
                            />
                        </a>
                    </li>
                    {menu.children.map((section, index) => {
                        if (section.isDisplayed) {
                            return (
                                <li
                                    key={section.pageSlug}
                                    className={
                                        this.state.currentUrl ===
                                        `/${section.pageSlug}`
                                            ? 'selected'
                                            : ''
                                    }
                                    onClick={() => {
                                        this.toggleMenu();
                                        this.updateComp(section.clickable
                                            ? `/${section.pageSlug}`
                                            : window.location.pathname);
                                    }}
                                >
                                    {section.clickable ? (
                                        <a href={`/${section.pageSlug}`}>
                                            {// <Link as={`/page/${section.pageSlug}`} href={`/page?_slug=${section.pageSlug}`}  >
                                                section.colorName ? (
                                                    <p
                                                        style={{
                                                            color : section.colorName,
                                                        }}
                                                        className={section.name}
                                                    >
                                                        {section.name}
                                                    </p>
                                                ) : (
                                                    <p className={section.name}>
                                                        {section.name}
                                                    </p>
                                                )}
                                        </a>
                                    ) : section.colorName ? (
                                        <p style={{ color: section.colorName }}>
                                            {section.name}
                                        </p>
                                    ) : (
                                        <p>{section.name}</p>
                                    )}
                                </li>
                            );
                        }
                        return <li key={section.pageSlug} />;
                    })}
                    <li className="no-hover">
                        <ul className="sub-menu">
                            {/* <SwitchLoginAccount /> */}
                            <li>
                                <a href="/cart">
                                    <img
                                        style={{ height: '20px' }}
                                        src="/medias/shopping-bag.png"
                                        alt="mon-panier"
                                    />
                                </a>
                            </li>
                            <li>
                                <img
                                    src="/medias/united-kingdom.png"
                                    alt="language"
                                    style={{
                                        display : 'inline-block',
                                        height  : '16px',
                                        width   : '16px',
                                    }}
                                />
                                {/* <i className="fa fa-chevron-down" style={{ display: 'inline-block', width: '40%' }} /> */}
                            </li>
                        </ul>
                    </li>
                </ul>
                <style jsx="true">{`
                    .menu {
                        width: 100%;
                        height: 61px;
                    }
                    .menu ul:not(.sub-menu) {
                        flex-direction: row;
                        justify-content: space-around;
                        flex-wrap: wrap;
                        padding: 0;
                        list-style: none;
                        display: flex;
                        margin: 0 auto;
                        height: 61px;
                        max-width: 1000px;
                    }

                    .menu ul:not(.sub-menu) li {
                        height: 61px;
                        padding: 0 5px;
                        cursor: pointer;
                        display: flex;
                        text-align: center;
                        flex-direction: column;
                        justify-content: center;
                        position: relative;
                        max-width: 120px;
                    }
                    .menu ul:not(.sub-menu) li p {
                        color: #fff;
                        text-decoration: none;
                        font-size: 19px;
                        margin: 0;
                        font-family: 'Oswald', sans-serif;
                        text-transform: uppercase;
                        font-size: 15px;
                    }
                    .menu ul:not(.sub-menu) li:not(.no-hover):hover:after,
                    .selected:after {
                        content: '';
                        position: absolute;
                        bottom: 0;
                        left: 50%;
                        transform: translateX(-50%);
                        width: 0;
                        height: 0;
                        border-bottom: 15px solid #fdbc58;
                        border-left: 10px solid transparent;
                        border-right: 10px solid transparent;
                    }
                    .menu ul:not(.sub-menu) li:hover p:not(.Locations),
                    .menu ul .selected p:not(.Locations) {
                        color: #fdbc58;
                    }
                    .disabled-link {
                        pointer-events: none;
                    }
                    .menu .menu-toggle {
                        display: none;
                    }
                    .menu ul:not(.sub-menu) li p.Locations {
                        padding: 5px;
                        background-color: #fdbc58;
                        color: #000;
                    }
                    .menu li .Locations:hover {
                        transform: scale(1.1);
                    }
                    .menu li a {
                        text-decoration: none;
                    }

                    @media screen and (max-width: 900px) {
                        .menu,
                        header .content,
                        header {
                            height: 70px;
                            overflow: hidden;
                        }
                        .menu ul:not(.sub-menu) {
                            flex-direction: column;
                            align-items: center;
                            height: auto;
                        }
                        .menu li {
                            flex-grow: 1;
                            height: 30px;
                        }
                        .menu .menu-toggle {
                            display: block;
                            position: absolute;
                            right: 10px;
                            top: 35px;
                            transform: translateY(-50%);
                            color: #fff;
                            cursor: pointer;
                            z-index: 1000;
                        }
                    }
                    ${this.cssHook};
                `}</style>
                {this.jsxHook}
            </div>
        );
    }
}
