import React from 'react';
import axios from 'axios';
import PropTypes from 'prop-types';
import getAPIUrl from '../lib/generateAPIUrl';
import { NSToast } from './NSToast';

export class NSNewsletter extends React.Component {
    constructor(props) {
        super(props);
        this.state = {
            email : null,
        };
    }

    static defaultProps = {
        button      : 'subscribe_button',
        placeholder : 'email_placeholder',
    }

    static proptypes = {
        button      : PropTypes.string,
        placeholder : PropTypes.string,
    }

    handleChange = async (e) => {
        this.setState({ email: e.target.value });
    };

    handleSubmit = async (e = undefined) => {
        e.preventDefault();
        if (!this.state.email) return;
        try {
            await axios.post(`${getAPIUrl()}v2/newsletter/${this.state.email}`, {
                name           : this.props.segment ? this.props.segment : 'Newsletter',
                isNew          : true,
                optin          : true,
                date_subscribe : new Date(),
            });
            NSToast.success('common:success_subscribe', this.props.i18n);
            this.setState({ email: '' });
            return;
        } catch (error) {
            NSToast.error('common:error_subscribe', this.props.i18n);
            this.setState({ email: '' });
        }
    };

    render() {
        const { email } = this.state;
        return (
            <form onSubmit={this.handleSubmit}>
                <div className="subscribe__form-inner">
                    <div className="subscribe__row">
                        <label htmlFor="subscribe_mail" className="hidden">{this.props.t('common:subscribe_email')}</label>
                        <input
                            type="email"
                            id="subscribe_mail"
                            value={email || ''}
                            name="subscribe_mail"
                            onChange={this.handleChange}
                            placeholder={this.props.t('common:subscribe_placeholder')}
                            className="subscribe__field"
                        />
                    </div>
                    <div className="subscribe__actions">
                        <button type="submit" value="GO" className="subscribe__btn">{this.props.t('common:subscribe_button')}</button>
                    </div>
                </div>
            </form>
        );
    }
}
