import React from 'react';
import Modal from 'react-responsive-modal';
import PropTypes from 'prop-types';
import { CartLib } from '../lib/CartLib';

/**
 * NSProductCard - Recupere en base le produit passé en props et l'affiche selon le render donné (par defaut, ouvre une popup pour le nombre de produit desirer puis ils sont ajouter au panier en validant)
 * @prop productid: (GUID) du produit dans Aquila
 *
 * |i|: Module npm du slider: react-slick
 *
 * @return {React.Component}
 */
export class NSProductCard extends React.Component {
    constructor(props, context) {
        super(props, context);
        this.state = {
            taxDisplay : context.getPageState().taxDisplay,
            product    : props.product,
            index      : props.index,
            id         : props.productid,
            open       : false,
            value      : 1,
        };
        this.toggleModal = this.toggleModal.bind(this);
        this.value = 1;
        this.cssHook = '';
        this.jsxHook = undefined;
    }

    static contextTypes = { getPageState: PropTypes.func };

    toggleModal() {
        this.setState({ open: !this.state.open });
    }

    onChangeValue = (e) => {
        this.value = Number(e.target.value);
        this.setState({ value: this.value });
    };

    render() {
        // const { productAsPath } = this.props;
        const { taxDisplay } = this.state;
        let time = 0;
        let circuit = 0;
        let taille = 0;
        let type = 'none';
        let info = 'none';
        if (this.state.product.attributes) {
            time = this.state.product.attributes.find(attr => attr.code === 'time').value;
            circuit = this.state.product.attributes.find(attr => attr.code === 'circuit').value;
            taille = this.state.product.attributes.find(attr => attr.code === 'taille').value;
            type = this.state.product.attributes.find(attr => attr.code === 'type').value;
            info = this.state.product.attributes.find(attr => attr.code === 'info').value;
        }
        // const asPath = productAsPath || this.props.url.asPath;
        const color = type === 'adultes' ? '#FDBC58' : (type === 'enfants' ? '#4EBBDE' : '#7EB620');

        return (
            <div
                className="product-card"
                onClick={(e) => {
                    this.props.clickable
                        ? this.toggleModal()
                        : console.log('ProductCard not clickable ...');
                }}
            >

                <link href="/static/css/product-card.css" rel="stylesheet" />
                <img
                    className="kart-image"
                    src={`../${this.state.product.imageUrl}`}
                    style={{ maxHeight: '130px' }}
                    alt="cart-image-card"
                />
                {this.state.product._id ? (
                    ''
                ) : (
                    <div
                        id="loading-spinner"
                        style={{
                            position : 'absolute',
                            top      : '0',
                            zIndex   : '101',
                            left     : '0%',
                            width    : '100%',
                        }}
                    >
                        <div
                            style={{
                                position   : 'absolute',
                                zIndex     : '100',
                                top        : '0',
                                right      : '0',
                                left       : '0',
                                bottom     : '0',
                                background : 'rgba(0, 0, 0, 0.5)',
                                height     : '580px',
                                width      : '100%',
                            }}
                        />
                        <i
                            className="fa fa-spinner fa-spin fa-2x"
                            style={{
                                position  : 'absolute',
                                color     : '#fff ',
                                top       : '50px',
                                zIndex    : '101',
                                left      : '43%',
                                transform : 'translateX(-50%)',
                            }}
                        />
                    </div>
                )}
                <div
                    className="top-svg"
                    dangerouslySetInnerHTML={{
                        __html : `<svg width='255' height='134' viewBox='0 0 255 134' version='1.1' xmlns='http://www.w3.org/2000/svg' xmlns:xlink='http://www.w3.org/1999/xlink'> <!-- Generator: Sketch 49.2 (51160) - http://www.bohemiancoding.com/sketch --> <desc>Created with Sketch.</desc> <defs></defs> <g id='LOCATION-ENFANTS' stroke='none' stroke-width='1' fill='none' fill-rule='evenodd'> <g id='LOCATIONS-ENFANTS' transform='translate(-592.000000, -831.000000)' fill='${color}'> <g id='TARIF' transform='translate(0.000000, 630.000000)'> <polygon id='Rectangle-2-Copy-2' points='592 201 847 201 847 303.524314 592 335'></polygon> </g> </g> </g> </svg>`,
                    }}
                />
                <h3>
                    {this.state.product.name}
                    {open}
                </h3>
                <hr
                    style={{
                        borderColor : color,
                        width       : '30%',
                        margin      : '20px auto',
                        display     : 'block',
                    }}
                />
                <div className="row vcenter">
                    <div className="col-3">
                        <img src="/medias/stopwatch.png" alt="time-image" />
                    </div>
                    <div className="col-9">
                        <p>{time}</p>
                    </div>
                </div>
                <div className="row vcenter">
                    <div className="col-3">
                        <img src="/medias/distance.png" alt="map-image" />
                    </div>
                    <div className="col-9">
                        <p>{circuit}</p>
                    </div>
                </div>
                <div className="row vcenter">
                    <div className="col-3">
                        <img src="/medias/scale.png" alt="length-image" />
                    </div>
                    <div className="col-9">
                        <p>{taille}</p>
                    </div>
                </div>
                <div className="row vcenter" hidden={type !== 'adultes'}>
                    <div className="col-3">
                        <img src="/medias/helmet.png" alt="length-image" />
                    </div>
                    <div className="col-9">
                        <p>{info}</p>
                    </div>
                </div>
                <div className="price-unit" hidden={this.props.cartdisplay}>
                    <p className="price">
                        {(this.state.product.price[taxDisplay].normal || 0).aqlRound(2)}€ <span>{t(`common:price.${taxDisplay}`)}</span>
                    </p>
                    <div
                        dangerouslySetInnerHTML={{
                            __html : `<svg width="255" height="70" viewBox="0 0 255 70" version="1.1" xmlns="http://www.w3.org/2000/svg"xmlns:xlink="http://www.w3.org/1999/xlink">                    <!-- Generator: Sketch 49.2 (51160) - http://www.bohemiancoding.com/sketch -->                    <desc>Created with Sketch.</desc>                    <defs></defs>                    <g id="LOCATION-ADULTES" stroke="none" stroke-width="1" fill="none" fill-rule="evenodd">                        <g id="LOCATIONS-ADULTES" transform="translate(-446.000000, -1284.000000)" fill="${color}">                            <g id="TARIFS" transform="translate(0.000000, 629.000000)">                                <polygon id="Rectangle-2-Copy-3" transform="translate(573.500000, 689.988281) scale(-1, -1) translate(-573.500000, -689.988281) " points="446 668.976562 701 655 701 711.822545 446 724.976562">test</polygon>                    </g>                        </g>                    </g> </svg>`,
                        }}
                    />
                </div>
                <div
                    className="row vcenter"
                    hidden={this.props.cartdisplay}
                    style={{
                        margin          : '-20px 0',
                        backgroundColor : '#E0E0E0',
                        padding         : '30px 0',
                        position        : 'relative',
                    }}
                >
                    <div className="col-3">
                        <img src="/medias/ticket.png" alt="ticket-image" />
                    </div>
                    <div className="col-9">
                        <p>
                            Pour l’achat de<br />
                            5 tickets de 10 min
                        </p>
                    </div>
                </div>
                <div className="price-group" hidden={this.props.cartdisplay}>
                    <p className="price">
                        {(this.state.product.price[taxDisplay].special || 0).aqlRound(2)}€ <span>{t(`common:price.${taxDisplay}`)}</span>
                    </p>
                    <div
                        dangerouslySetInnerHTML={{
                            __html :
                                '<svg width="255" height="70" viewBox="0 0 255 70" version="1.1" xmlns="http://www.w3.org/2000/svg"xmlns:xlink="http://www.w3.org/1999/xlink">                    <!-- Generator: Sketch 49.2 (51160) - http://www.bohemiancoding.com/sketch -->                    <desc>Created with Sketch.</desc>                    <defs></defs>                    <g id="LOCATION-ADULTES" stroke="none" stroke-width="1" fill="none" fill-rule="evenodd">                    <g id="LOCATIONS-ADULTES" transform="translate(-446.000000, -1442.000000)" fill="#9B9B9B">                    <g id="TARIFS" transform="translate(0.000000, 629.000000)">                    <polygon id="Rectangle-2-Copy-7" transform="translate(573.500000, 847.988281) scale(-1, -1) translate(-573.500000, -847.988281) " points="446 826.976562 701 813 701 869.822545 446 882.976562"></polygon>                    </g>                    </g>                    </g>                    </svg>',
                        }}
                    />
                </div>
                <style jsx="true">
                    {`
                        .product-card {
                            max-width: 255px;
                            position: relative;
                            background-color: #fff;
                            color: #000;
                            margin: 0 auto;
                            margin-top: 50px;
                            height: 600px;
                            cursor: pointer;
                            padding-bottom: ${type === 'adultes'
                ? '680px'
                : '0'};
                        }
                        .product-card * {
                            font-family: Oswald, sans-serif;
                        }
                        .product-card .kart-image {
                            top: 10px;
                            position: absolute;
                            left: 50%;
                            max-width: 90%;
                            transform: translateX(-50%);
                        }
                        .product-card h3 {
                            color: #000;
                            text-transform: none;
                            margin-top: 10px;

                            font-size: 28px;
                            text-align: center;
                            font-weight: bold;
                            font-family: Oswald, sans-serif;
                        }
                        .vcenter {
                            display: flex;
                            align-items: center;
                            margin: 20px 0;
                        }
                        .product-card p {
                            color: #000;
                            text-align: left;
                            margin: 0;
                        }
                        .product-card .row img {
                            margin: 0 auto;
                            display: block;
                        }
                        .product-card .price-unit,
                        .product-card .price-group {
                            position: relative;
                            z-index: 2;
                        }
                        .product-card .price-unit .price,
                        .product-card .price-group .price {
                            position: absolute;
                            z-index: 2;
                            right: 10px;
                            line-height: 70px;
                            margin: 0;
                            font-size: 30px;
                            font-weight: bold;
                        }
                        .product-card .price-unit .price span,
                        .product-card .price-group .price span {
                            font-size: 16px;
                            color: #000;
                        }
                        ${this.cssHook};
                    `}
                </style>
                <Modal
                    open={this.state.open}
                    onClose={() => this.toggleModal()}
                    classNames={{
                        modal   : 'custom-modal',
                        overlay : 'custom-overlay',
                    }}
                    little
                >
                    <img
                        src={`../${this.state.product.imageUrl}`}
                        alt="product-image"
                        className="product-image"
                    />
                    <h3>{this.state.product.name}</h3>
                    <hr style={{ borderColor: color, width: '30%' }} />
                    <div className="row vcenter">
                        <div className="col-3">
                            <img src="/medias/ticket.png" alt="ticket" />
                        </div>
                        <div className="col-9">
                            <input
                                type="number"
                                name="nbTicket"
                                value={this.value}
                                min="1"
                                style={{
                                    width  : '100%',
                                    border : '1px solid #aaa',
                                }}
                                onChange={
                                    this.onChangeValue
                                } /* onChange={e => this.value = e.target.value} */
                            />
                        </div>
                    </div>
                    <div className="row vcenter">
                        <div className="col-9 offset-3">
                            <p>
                                <b>Réduction !</b>
                            </p>
                            <p>Si vous achetez 5 tickets de 10 min !</p>
                        </div>
                    </div>
                    <button
                        className="btn center-block"
                        onClick={e => CartLib.addToCartV2(this.state.product)}
                    >
                        AJOUTER AU PANIER
                    </button>
                    <style jsx="true">
                        {`
            .custom-modal {
                border: 5px solid ${color} !important;
            }
            .custom-modal .product-image {
                width: 300px;
                height: 300px;
                object-fit: contain;
            }
            .custom-modal h3 {
                font-family: Oswald, sans-serif;
                text-align: center;
            }
            .custom-modal .row, .custom-modal .row p {
                margin: 0;
                font-family: Oswald, sans-serif;
                font-size: 14px;
            }
            .custom-modal input {
                text-align: right;
            }

            .custom-modal .btn {
                color: #fff;
                background: ${color};
                border-radius: unset;
                text-transform: uppercase;
                font-family: Oswald;
                font-size: 16px;
                padding: 2px 5px;
                display: block;
                margin: 30px auto 0 auto;
            }

            .custom-modal .btn:hover {
                transform: scale(1.1);
            }
    `}
                    </style>
                </Modal>
                {this.jsxHook}
            </div>
        );
    }
}
