import React from 'react';
import PropTypes from 'prop-types';
import statusColor from '../lib/statusColor';

/**
 * NSProductStock - Affichage du label de stock pour un produit et la disponibilité
 * @return {React.Component}
 */
export class NSProductStock extends React.Component {
    static contextTypes = { getPageState: PropTypes.func };


    constructor(props) {
        super(props);
        this.state = {
            stockData : [],
        };
        this.cssHook = '';
        this.jsxHook = undefined;
    }

    UNSAFE_componentWillMount() {
        if (
            this.context
            && this.context.getPageState()
            && this.context.getPageState().stockData
        ) {
            this.setState({ stockData: this.context.getPageState().stockData });
        }
    }

    componentWillReceiveProps(props) {
        this.setState({ ...props, stockData: this.context.getPageState().stockData });
    }

    getAvailability(status) {
        switch (status) {
        case 'liv':
            return 'InStock';
        case 'dif':
            return 'PreOrder';
        case 'epu':
            return 'OutOfStock';
        default: 'OutOfStock';
        }
    }

    render() {
        const { stockData } = this.state;
        return (
            <div className="ns-product-stock">
                <link rel="stylesheet" href="/static/css/product-stock.css" />
                <span itemProp="availability" itemType={`http://schema.org/${this.getAvailability(stockData.status)}`} className={`ns-label-stock ns-label-${stockData.status}`}>{statusColor(stockData.status)}</span>

                <div className="ns-availability-stock">
                    <p>
                        {stockData.label ? <strong>{stockData.label}</strong> : ''}
                    </p>
                </div>
                <style jsx="true">{`
                    ${this.cssHook};
                `}</style>
                {this.jsxHook}
            </div>
        );
    }
}
