import React from 'react';
import axios from 'axios';
import {NSToast} from './NSToast';
import getAPIUrl from '../lib/generateAPIUrl';


/**
 * NSRegister - Affiche le formulaire d'inscription puis envoie la requete au serveur et vous connectant en cas de succes
 * @prop none
 * State - register: (object) contient 5 couple clé/valeur, firstname (string), lastname (string), email (string), password (string), passwordConfirm (string)
 * /!\ BUG AU NIVEAU DES TOASTS /!\
 *
 * @return {React.Component}
 */
export class NSRegister extends React.Component {
    constructor(props) {
        super(props);
        this.state = {
            register : {
                firstname       : '',
                lastname        : '',
                email           : '',
                password        : '',
                passwordConfirm : '',
            },
        };
        this.handleRegisterChange = this.handleRegisterChange.bind(this);
        this.handleRegisterSubmit = this.handleRegisterSubmit.bind(this);
        this.cssHook = '';
        this.jsxHook = undefined;
    }

    handleRegisterChange(event) {
        const register = {
            ...this.state.register,
            [event.target.name] : event.target.value,
        };
        this.setState({ register });
    }

    async handleRegisterSubmit(event) {
        try {
            event.preventDefault();
            const { password, passwordConfirm, email } = this.state.register;
            if (password === passwordConfirm) {
                const jwtToken = await axios.post(`${getAPIUrl()}v2/auth/login`, { username: email, password });
                axios.defaults.headers.common.Authorization = jwtToken.data.data;
                let customRoute;
                if (this.props.fromCart) customRoute = '/cart/billing';
                window.location.pathname = '/account';
            } else {
                NSToast.error('Vos mots de passe doivent être identiques.');
                this.state.register.password = '';
                this.state.register.passwordConfirm = '';
                this.setState({ register: this.state.register });
            }
        } catch (err) {
            if (err.response && err.response.data.message) {
                console.error(err.response.data.message);
                NSToast.error(err.response.data.message);
                this.setState({ regError: err.response.data.message });
            }
        }
    }

    render() {
        const {
            firstname,
            lastname,
            email,
            password,
            passwordConfirm,
        } = this.state.register;
        return (
            <div className="newClient">
                <h2 className="title">
                    NOUVEAU CLIENT ? <br />
                    INSCRIVEZ-VOUS !
                </h2>
                <form
                    style={{ marginTop: '50px' }}
                    onSubmit={e => this.handleRegisterSubmit(e)}
                >
                    <div className="form-group row vcenter fieldsClient">
                        <label
                            htmlFor="lastname"
                            name="lastname"
                            className="col-md-3 col-form-label"
                        >
                            Nom<span className="requireField">*</span>
                        </label>
                        <div className="col-md-9">
                            <input
                                id="lastname"
                                type="text"
                                name="lastname"
                                value={lastname}
                                onChange={this.handleRegisterChange}
                                required
                            />
                        </div>
                    </div>
                    <div className="form-group row vcenter fieldsClient">
                        <label
                            htmlFor="firstname"
                            className="col-md-3 col-form-label"
                        >
                            Prenom<span className="requireField">*</span>
                        </label>
                        <div className="col-md-9">
                            <input
                                id="firstname"
                                type="text"
                                name="firstname"
                                value={firstname}
                                onChange={this.handleRegisterChange}
                                required
                            />
                        </div>
                    </div>
                    <div className="form-group row vcenter fieldsClient">
                        <label
                            htmlFor="email"
                            className="col-md-3 col-form-label"
                        >
                            Adresse mail<span className="requireField">*</span>
                        </label>
                        <div className="col-md-9">
                            <input
                                id="email"
                                type="text"
                                name="email"
                                value={email}
                                onChange={this.handleRegisterChange}
                                required
                            />
                        </div>
                    </div>
                    <div className="form-group row vcenter fieldsClient">
                        <label
                            htmlFor="password"
                            className="col-md-3 col-form-label"
                        >
                            Mot de passe<span className="requireField">*</span>
                        </label>
                        <div className="col-md-9">
                            <input
                                id="password"
                                type="password"
                                name="password"
                                value={password}
                                onChange={this.handleRegisterChange}
                                required
                                ref={input => (this.pass1 = input)}
                            />
                        </div>
                    </div>
                    <div className="form-group row vcenter fieldsClient">
                        <label
                            htmlFor="passwordConfirm"
                            className="col-md-3 col-form-label"
                        >
                            Confirmer le <br />mot de passe<span className="requireField">
                                *
                            </span>
                        </label>
                        <div className="col-md-9">
                            <input
                                id="passwordConfirm"
                                type="password"
                                name="passwordConfirm"
                                value={passwordConfirm}
                                onChange={this.handleRegisterChange}
                                required
                                ref={input => (this.pass2 = input)}
                            />
                            <div className="requiredLabel">
                                *Champs obligatoires
                            </div>
                            <button type="submit">VALIDER</button>
                        </div>
                    </div>
                    {/* <div className="fieldsNewClient">
                        <div className="labels">
                            <label htmlFor="lastname">Nom<span className="requireField">*</span></label>
                            <label htmlFor="firstname">Prenom<span className="requireField">*</span></label>
                            <label htmlFor="email">Adresse mail<span className="requireField">*</span></label>
                            <label htmlFor="password">Mot de passe<span className="requireField">*</span></label>
                            <label className="passwordConfirm" htmlFor="passwordConfirm">Confirmer le <br />mot de passe<span className="requireField">*</span></label>
                        </div>
                        <div className="inputs">
                            <input id="lastname" type="text" name="lastname" value={lastname} onChange={this.handleRegisterChange} required />
                            <input id="firstname" type="text" name="firstname" value={firstname} onChange={this.handleRegisterChange} required />
                            <input id="email" type="email" name="email" value={email} onChange={this.handleRegisterChange} required />
                            <input id="password" type="password" name="password" value={password} onChange={this.handleRegisterChange} required ref={(input) => this.pass1 = input} />
                            <input id="passwordConfirm" type="password" name="passwordConfirm" value={passwordConfirm} onChange={this.handleRegisterChange} required ref={(input) => this.pass2 = input} />
                            <div className="requiredLabel">*Champs obligatoires</div>
                            <button type="submit">VALIDER</button>
                        </div>
                    </div> */}
                </form>

                <style jsx="true">{`
                    .newClient {
                        color: white;
                    }
                    .newClient .title {
                        font-size: 30px;
                        color: #fdbc58;
                        text-align: center;
                    }
                    .requireField {
                        color: #fdbc58;
                    }
                    button {
                        color: white;
                        background: rgb(253, 188, 88);
                        font-size: 22px;
                        border: none;
                        cursor: pointer;
                        text-align: center;
                        line-height: 35px;
                        width: fit-content;
                        margin-top: 8px;
                        transition: 0.4s;
                        padding-right: 10px;
                        padding-left: 10px;
                    }
                    button:hover {
                        background: rgb(247, 174, 63);
                    }
                    input {
                        background: black;
                        border: 1px solid white;
                        width: 100%;
                        height: 40px;
                        border-radius: 0;
                        margin-top: 8px;
                        margin-bottom: 8px;
                        color: white;
                        padding-left: 10px;
                    }
                    .newClient {
                        display: flex;
                        flex-direction: column;
                        width: 100%;
                        padding-top: 30px;
                    }
                    .fieldsNewClient {
                        display: flex;
                        justify-content: center;
                        flex-direction: row;
                    }
                    .labels,
                    .inputs {
                        display: flex;
                        flex-direction: column;
                    }
                    .labels {
                        padding-right: 35px;
                    }

                    label {
                        display: block;
                        height: 50px;
                        text-align: right;
                        height: 48px;
                        padding: 0;
                        padding-top: 15px;
                    }
                    .passwordConfirm {
                        padding-top: 5px !important;
                    }
                    label span {
                        vertical-align: middle;
                    }
                    .requiredLabel {
                        font-size: 13px;
                        color: #fdbc58;
                        letter-spacing: 0;
                        text-align: right;
                        line-height: 21px;
                    }
                    @media screen and (max-width: 990px) {
                        .newClient {
                            margin-top: 100px;
                        }
                        .fieldsNewClient {
                            margin-top: 30px;
                        }
                        button {
                            align-self: center;
                        }
                        label {
                            text-align: center;
                        }
                        label[for='passwordConfirm'] {
                            margin-bottom: 20px;
                        }
                    }
                    ${this.cssHook};
                `}</style>
                {this.jsxHook}
            </div>
        );
    }
}
