import React from 'react';
import Slider from 'react-slick';
import PropTypes from 'prop-types';

/**
 * NSSlider - Charge les informations du slider (via son ns-code), affiche les image en permettant un slide lattéral
 * @prop ns-code: (string) code du carrousel dans Aquila
 * @return {React.Component}
 */
export class NSSlider extends React.Component {
    constructor(props) {
        super(props);
        this.state = {
            isDragging : false,
        };
        this.cssHook = '';
        this.jsxHook = undefined;
    }

    static contextTypes = { getPageState: PropTypes.func };
    shouldComponentUpdate(nextProps, nextState) {
        return this.state.isDragging === nextState.isDragging;
    }

    loadPage = (e) => {
        if (this.state.isDragging) {
            e.preventDefault();
        }
    }

    render() {
        const code = this.props['ns-code'];
        const nsSlider = this.context.getPageState()[`nsSlider_${code}`];
        if (!nsSlider) {
            return (
                <div>{this.props.t('common:error.loadDataComponent', { component: 'NSSlider' })}</div>
            );
        }
        nsSlider.items = nsSlider.items.sort((a, b) => a.order > b.order);
        const { items } = nsSlider;
        // Création des settings
        const settings = {
            ...nsSlider,
            autoplay       : true,
            arrows         : true,
            adaptiveHeight : false,
            dots           : true,
            beforeChange   : () => this.setState({ isDragging: true }),
            afterChange    : () => this.setState({ isDragging: false }),
        };
        return (
            <div>
                <link
                    rel="stylesheet"
                    type="text/css"
                    href="/static/slick-1.6.0/slick_and_theme.css"
                />
                <link rel="stylesheet" href="/static/css/slider.css" />
                <div className="NSSlider">
                    <Slider {...settings} style={{ width: '100%' }}>
                        {items.sort((a, b) => a.order - b.order).map(item => (
                            <div key={item._id} style={{ width: '100%' }}>
                                {item.href ? (
                                    <a href={item.href}>
                                        <img
                                            style={{ width: '100%' }}
                                            onClick={this.loadPage}
                                            src={`/${item.src}`}
                                            alt={item.text}
                                            title={item.text}
                                            className="imgSlide"
                                        />
                                    </a>
                                ) : (
                                    <img
                                        style={{ width: '100%' }}
                                        onClick={this.loadPage}
                                        src={`/${item.src}`}
                                        alt={item.text}
                                        title={item.text}
                                        className="imgSlide"
                                    />
                                )}
                            </div>
                        ))}
                    </Slider>
                </div>
            </div>
        );
    }
}
