import React, { Component } from 'react';
import { isServer } from '../lib/helpers';

export class NSToast extends Component {
    static defaultProps = {
        duration         : 5000,
        bgSuccess        : '#2E8B57',
        bgError          : '#C92C2C',
        bgWarn           : '#ffa500',
        colorTextSuccess : '#fff',
        colorTextError   : '#fff',
        colorTextWarn    : '#fff'
    };

    static success = (msg, i18n = undefined, duration = undefined) => {
        if (typeof window === 'undefined') return;
        const event =  new CustomEvent('showToast', { detail: { msg, type: 'success', i18n, duration } });
        dispatchEvent(event);
    };

    static error = (msg, i18n = undefined, duration = undefined) => {
        if (typeof window === 'undefined') return;
        const event =  new CustomEvent('showToast', { detail: { msg, type: 'error', i18n, duration } });
        dispatchEvent(event);
    };

    static warn = (msg, i18n = undefined, duration = undefined) => {
        if (typeof window === 'undefined') return;
        const event =  new CustomEvent('showToast', { detail: { msg, type: 'warn', i18n, duration } });
        dispatchEvent(event);
    }

    constructor(props) {
        super(props);
        this.state = {
            show : false,
            type : '',
            msg  : '',
        };

        this.mounted = true;
    }

    componentDidMount() {
        if (typeof window !== 'undefined') {
            window.addEventListener('showToast', (e) => {
                let message = e.detail.msg;
                if (e.detail.i18n !== undefined && message) {
                    const [ns, key] = message.split(':');
                    if (key !== undefined)
                        message = e.detail.i18n.getResource(e.detail.i18n.language, ns, key);
                }
                if (this.mounted) this.setState({ show: true, msg: message, type: e.detail.type });
                setTimeout(() => {
                    if (this.mounted) this.setState({ show: false });
                }, e.detail.duration || this.props.duration);
            });
        }
    }

    componentWillUnmount() {
        this.mounted = false;
    }

    render() {
        const { show, type, msg } = this.state;
        const {
            bgError, bgSuccess, bgWarn, colorTextError, colorTextSuccess, colorTextWarn,
        } = this.props;
        let bgColor = '';
        let textColor = '';
        if (type === 'error') {
            bgColor = bgError;
            textColor = colorTextError;
        } else if (type === 'warn') {
            bgColor = bgWarn;
            textColor = colorTextWarn;
        } else {
            bgColor = bgSuccess;
            textColor = colorTextSuccess;
        }
        return (
            <div className="toast" hidden={!show}>
            <link rel="stylesheet" href="/static/css/toast.css"/>
                <p>{msg}</p>
                <style jsx="true">
                    {`
                        .toast {
                            background: ${bgColor} !important;
                        }
                        .toast p {
                            color: ${textColor};
                        }
                    `}
                </style>
            </div>
        );
    }
}