import axios from 'axios';
import getAPIUrl from './generateAPIUrl';

export const CartLib = {
    addToCart(product, qty, onSuccess, onError, selections = undefined) {
        axios.put(`${getAPIUrl()}v2/cart/item`, {
            cartId : window.localStorage.getItem('cart_id'),
            item   : {
                id       : product._id, quantity : qty, weight   : product.weight, selections,
            },
        }).then((response) => {
            if (onSuccess) onSuccess(response.data);
        }).catch((err) => {
            window.localStorage.removeItem('cart_id')
            if (onError) onError(err);
        });
    },
    addToCartKdo(product, qty, parent = undefined, onSuccess, onError) {
        if (parent) {
            axios.put(`${getAPIUrl()}v2/cart/item`, {
                cartId : window.localStorage.getItem('cart_id'),
                item   : { id: product._id, quantity: qty, parent: parent._id },
            }).then((response) => {
                if (onSuccess) onSuccess(response.data);
            }).catch((err) => {
                if (onError) onError(err);
            });
        }
    },
    addToCartV2(product, qty, onSuccess, onError) {
        this.addToCart(
            product,
            qty,
            (cart) => {
                if (onSuccess) { onSuccess(cart); }     // onSuccess
            },
            (err) => {
                if (onError) { onError(err); }     // onSuccess
            },
        );
    },
    addToCartBundleProduct(body, onSuccess, onError) {
        this.addToCart(
            body.item,
            1,
            (cart) => {
                if (onSuccess) { onSuccess(cart); }     // onSuccess
            },
            (err) => {
                if (onError) { onError(err); }     // onSuccess
            },
            body.item.selections,
        );      
    },
};
