import axios from 'axios';

export default componentLoader;


// Ajouter dans ce tableau le tag des composant ayant l'autorisatiopn d'effectuer des requetes api (whitelist)
const allowedComponents = ['ns-cms', 'ns-menu', 'ns-cross', 'ns-cross-selling', 'ns-slider', 'ns-gallery', 'ns-block-slider', 'ns-calendar', 'ns-blog-articles'];
/**
 * Cette fonction permet de charger recursivement les datas des composants ou blockCMS
 * Exemple:
 *  <main>
        <h1>page-de-test</h1>
        <ns-search></ns-search>
        <ns-cms ns-code="test"></ns-cms>
        <ns-menu ns-code="la-carte-0"></ns-menu>
    </main>
    Ici le componentLoader va chercher les element commencant par <ns- ayant un ns-code ex: <ns-cms ns-code="test"></ns-cms>
    si c'est un blockCMS (qui commence par ns-cms) alors nous allons charger les composants de ce blockCMS, une fois chargé nous
    allons remplacer <ns-cms ns-code="test"></ns-cms> par ses composants et son html
    <main>
        <h1>page-de-test</h1>
        <ns-search></ns-search>
        <h1>CMS Test</h1> //HTML venant du blockCMS <ns-cms ns-code="test">
        <ns-slider ns-code="slider3"></ns-slider> //composant venant du blockCMS <ns-cms ns-code="test">
        <ns-slider ns-code="slider2"></ns-slider> //composant venant du blockCMS <ns-cms ns-code="test">
        <ns-menu ns-code="la-carte-0"></ns-menu>
    </main>
 * @param {*} doc datas recupérées de la base de données via l'API /api/v2/static avec pour param un PostBody allant chercher le slug
 * @param {*} oComponentsData objet dans lequel nous allons mettre les datas des composants chargés
 */
async function componentLoader(doc, oComponentsData = {}, API_url, lang) {
    if (!doc || !doc.content) return oComponentsData;
    // On recherche les balises commencant par "<ns-" et contenant ns-code ex: <ns-uncomposant ns-code="codeDuComposant">
    // Si nous n'avons pas de ns-code nous n'avons aucune données a recupérer en base
    const tBaliseAndCode = doc.content.match(/(<ns-.*?>)/g);
    if (!tBaliseAndCode || !tBaliseAndCode.length) return oComponentsData;
    // On construit les objets "oTag" et on les ajoutes dans le tableau "tBaliseToSend"
    const tBaliseToSend = [];
    for (let i = 0; i < tBaliseAndCode.length; i++) {
        if (!tBaliseAndCode[i].startsWith('<ns-')) continue;
        // tableau d objet de forme {tag : "ns-slider", code : "5ab2791fbb62db2c60335458" }

        const oTag = {
            tag   : '', code  : '', type  : '', limit : 99
        };
        const tag = tBaliseAndCode[i].match(/<(ns-[a-zA-Z0-9-]*)/);
        oTag.tag = tag ? tag[1] : '';

        const codeTmp = tBaliseAndCode[i].match(/ns-code=['"]([a-zA-Z0-9-_,\s]+)["']/);
        oTag.code = codeTmp ? codeTmp[1] : ''; // Pour "ns-menu" et "ns-cms" notamment

        const type = tBaliseAndCode[i].match(/type=['"]([a-zA-Z0-9-_\s]+)["']/);
        oTag.type = type ? type[1] : '';

        if (oTag.tag === 'ns-blog-articles')
        {
            const limit = tBaliseAndCode[i].match(/limit=['"](\d+)["']/);
            oTag.limit = limit ? Number(limit[1]) : 99; // Pour "ns-blog-articles"
        }

        tBaliseToSend.push(oTag);
    }

    // Nous allons itérer recursivement a travers le tableau "tBaliseToSend"
    for (const balise of tBaliseToSend) {
        try {
            if (allowedComponents.indexOf(balise.tag) > -1) {
                if (balise.tag === 'ns-cross' || balise.tag === 'ns-cross-selling') {
                    const response = await axios.post(`${API_url}v2/products`, {
                        lang,
                        PostBody : {
                            filter    : balise.type !== 'new' ? { attributes: { $elemMatch: { code: balise.type, [`translation.${lang}.value`]: true } }, active: true, _visible: true } : { is_new: true, active: true, _visible: true },
                            structure : {
                                attributes      : 1,
                                canonical       : 1,
                                bundle_sections : 1,
                                code            : 1
                            },
                            populate : ['bundle_sections.products.id'],
                            limit    : 99,
                        },
                    });
                    const tTags = balise.tag.split('-');
                    const newTags = `${tTags[0] +
                    capitalizeFirstLetter(tTags[1])}_${balise.code}`;
                    oComponentsData[newTags] = response.data;
                } else if (balise.tag === 'ns-cms') {
                    // Récupération des données du blockCMS
                    // Si elles ont déjà été récupérées, inutile de continuer
                    if (oComponentsData[`nsCms_${balise.code}`] !== undefined)
                        continue;
                    const response = await axios.post(`${API_url}v2/component/${balise.tag}/${balise.code}`, { lang });
                    if (response.err || response.data === null) {
                        console.error('\x1b[31m%s\x1b[0m', `Error: {tag: ${balise.tag}, nsCode: ${balise.code}}`);
                    }
                    
                    // On place les données du bloc CMS dans une entrée de type "nsCms_[ns-code]"
                    oComponentsData[`nsCms_${balise.code}`] = response.data;

                    // Recherche récursive de blockCMS
                    await componentLoader(
                        response.data,
                        oComponentsData,
                        API_url,
                        lang,
                    );
                } else if (balise.tag === 'ns-blog-articles') {
                    // Récupération des articles du blog
                    const response = await axios.post(`${API_url}v2/site/news`, {
                        lang,
                        PostBody : {
                            filter : {
                                isVisible : true,
                                [`translation.${lang}`]: {$exists: true}
                            },
                            sort  : '-createdAt',
                            page  : 1,
                            limit : balise.limit,
                        },
                    });
                    if (response.err || response.data.datas.length === 0) {
                        console.error('\x1b[31m%s\x1b[0m', `Error: {tag: ${balise.tag}, nsCode: ${balise.code}}`);
                    }
                    // On place le tableau des données des blocs CMS dans une entrée de type "nsBlogArticles"
                    oComponentsData.nsBlogArticles = response.data.datas;
                } else if (balise.tag === 'ns-block-slider') {
                    const codes = balise.code.split(',');
                    const promises = [];
                    const cms   = [];
                    for (let i = 0; i < codes.length; i++) {
                        promises.push(await axios.post(`${API_url}v2/component/ns-cms/${codes[i].trim()}`, { lang }));
                    }
                    const resCms = await axios.all(promises);
                    for (let i = 0; i < resCms.length; i++) {
                        cms.push(resCms[i].data);
                    }
                    
                    // On place le tableau des données des blocs CMS dans une entrée de type "nsBlockSlider_[ns-code]"
                    oComponentsData[`nsBlockSlider_${balise.code}`] = cms;
                } else {
                    if (balise.tag === 'ns-btn' || balise.tag === 'ns-search') continue;
                    const response = await axios.post(`${API_url}v2/component/${balise.tag}/${balise.code}`, { lang });
                    if (response.err || response.data === null) {
                        console.error('\x1b[31m%s\x1b[0m', `Error: {tag: ${balise.tag}, nsCode: ${balise.code}}`);
                    }
                    const tTags = balise.tag.split('-');
                    const newTags = `${tTags[0] +
                    capitalizeFirstLetter(tTags[1])}_${balise.code}`;
                    // ns-slider sera maintenant nsSlider_leCode
                    oComponentsData[newTags] = response.data;
                }
            }
        } catch (error) {
            // console.error(error);
        }
    }
    return oComponentsData;
}

function capitalizeFirstLetter(string) {
    return string.charAt(0).toUpperCase() + string.slice(1);
}
