import axios from 'axios';
import getAPIUrl from './generateAPIUrl';
import jwtManager from './jwtManager';

/**
 * Fonction recupérant le jwt du client et verifiant sa validité, si valide alors on enregistre le nouveau token,
 * sinon on supprime le token non valide du client
 */
export async function isAuth() {
    try {
        if (!jwtManager.get()) throw 'not loggedin';
        const isLogged = await axios.get(`${getAPIUrl()}v2/auth/isauthenticated`);
        // Si le token est valide alors on l'enregistre et on met a jour l'état
        if (!isLogged.data.isAuthenticate) {
            await jwtManager.remove();
        }
        return { isLogged: isLogged.data.isAuthenticate, client: isLogged.data.user.info || isLogged.data.user };
    } catch (error) {
        await jwtManager.remove();
        return { isLogged: false, client: null };
    }
}
