import axios from 'axios';
import generateAPIUrl from './generateAPIUrl';
import { base64ToString } from './helpers';

function cookiesParse(cookies) {
    const item = cookies.match('.*?jwt=(.*?);.*|.*?jwt=(.*?)$');
    if (item) {
        return (item[1] || '') + (item[2] || '');
    }
    return '';
}

export default {
    /**
     * @param ctx
     * @returns {*|string}
     */
    get(ctx) {
        if (ctx && ctx.req && ctx.req.headers.cookie) {
            return cookiesParse(ctx.req.headers.cookie);
        }
        if (process.browser) {
            return cookiesParse(document.cookie);
        }
    },
    async remove() {
        const res = await axios.get(`${generateAPIUrl()}v2/auth/logout`);
        if (res) {
            delete axios.defaults.headers.common.Authorization;
        }
    },
    getUser(ctx) {
        const jwt = this.get(ctx);
        if (jwt) {
            return JSON.parse(base64ToString(jwt.split('.')[1])).info;
        }
    },
    getTaxDisplay(ctx) {
        const user = this.getUser(ctx);
        if (user) {
            return user.taxDisplay === false ? 'et' : 'ati';
        }
        return 'ati';
    }
};
