import React from "react";
import axios from 'axios';
import moment from "moment";
import PropTypes from 'prop-types';
import getAPIUrl from '../lib/generateAPIUrl';
import { initPage } from "../lib/helpers";
import { NSBreadcrumb } from '../components/NSBreadcrumb';

export class NSBlogArticle extends React.Component {
    static getInitialProps = async function (req) {
        const langs = await axios.post(`${getAPIUrl(req)}v2/languages`, { PostBody: { limit: 99 } });
        const lang  = req.query.lang || langs.data.datas.find(l => l.defaultLanguage === true).code;

        const res = await axios.post(`${getAPIUrl(req)}v2/site/new`, {
            lang,
            PostBody : {
                filter : {
                    [`translation.${lang}.slug`] : req.query._slug,
                },
            }
        });

        let pathUrl = '';
        if (req.req) {
            pathUrl = `${req.req.protocol}://${req.req.headers.host}`;
        } else {
            pathUrl = `${window.location.origin}`;
        }

        // On recupère les blocs cms
        const initData = await initPage(req, lang);
        return {
            article: res.data,
            nsLanguages: langs.data,
            url: {
                asPath : req.asPath,
            },
            query: req.query,
            ...initData,
            pathUrl
        };
    };

    constructor(props) {
        super(props);
        this.state = {
            ...props
        };
    }

    onLangChange = (lang, Router) => {
        const defaultCode = this.props.nsLanguages.find(l => l.defaultLanguage === true).code;
        const params = {
            _slug   : this.props.article.slug[lang]
        };
        if (lang !== defaultCode) {
            params.lang = lang;
        }
        Router.pushRoute('blogArticle', params).then(() => { window.location.pathname = Router.router.asPath; });
    };

    render() {
        const {oCmsHeader, oCmsFooter, article} = this.props;
        let pathUrl = this.props.pathUrl;
        if (pathUrl === "") {
            pathUrl = window.location.href;
        }
        const url = pathUrl ? `${pathUrl.split("/")[0]}//${pathUrl.split("/")[2]}` : "";
        return (
            <div className="main__inner">
                <div className="shell blog">
                    <NSBreadcrumb />
                    <section className="section section--table ns-article" key={article.slug} itemScope="" itemType="http://schema.org/Article">
                        <div className="shell">
                            <h1 className="section__title">
                                <span itemProp="headline">{article.title}</span>
                            </h1>

                            <div itemProp="image" itemScope="" itemType="http://schema.org/ImageObject">
                                <meta itemProp="url" content={`${url}/${article.img}`} />
                            </div>

                            <div className="section__body">
                                <div className="section__inner">
                                    <div className="article-date" itemProp="datePublished" content={moment(article.createdAt).format("DD/MM/YYYY - HH[h]mm")}>
                                        {moment(article.createdAt).format("DD/MM/YYYY - HH[h]mm")}
                                    </div>
                                    <div itemProp="articleBody" className="ns-article-content" dangerouslySetInnerHTML={{__html: (article.img ? `<img src=${url}/${article.img} alt=${article.img} />` : '') + article.content.text}} />
                                </div>
                            </div>
                        </div>
                    </section>
                </div>
            </div>
        );
    }

    getChildContext() {
        return {
            getPageState : () => this.state,
            onLangChange : (lang, Router) => this.onLangChange(lang, Router),
        };
    }

    static childContextTypes = {
        getPageState : PropTypes.func,
        onLangChange : PropTypes.func,
    };
}