import React from 'react';
import axios from 'axios';
import PropTypes from 'prop-types';
import componentLoader from '../lib/componentLoader';
import { initPage } from '../lib/helpers';
import getAPIUrl from '../lib/generateAPIUrl';

/**
 * NSPage - Charge le HTML des pages statiques dans un dangerouslySetInnerHTML par default (extends pour y ajouter un composant CMS custom)
 * @prop oCmsHeader: (object) bloc CMS Header
 * @prop oCmsFooter: (object) bloc CMS Footer
 * @prop isEmpty: (bool) etat de la page actuelle, "true" si la page est vide
 * @prop notFount: (bool) vaut "true" si la page est introuvable
 * State - oCmsHeader: (object) bloc CMS Header
 * State - oCmsFooter: (object) bloc CMS Footer
 * @return {React.Component}
 */
export class NSPage extends React.Component {
    static getInitialProps = async function (req) {
        try {
        // On charge la page static pouvant contenir plusieurs BlocCMS comportant eu même plusieurs composant a charger
            let { _slug } = req.query;
            const langs = { data: [] };// await axios.post(`${getAPIUrl(req)}v2/languages`, { PostBody: { limit: 99 } });
            const lang = 'fr';// req.req ? req.req.i18n.language : langs.data.datas.find(l => l.defaultLanguage === true).code;

            const initData = await initPage(req, lang);

            let params = '';
            if (req.query.preview) {
                params = `?preview=${req.query.preview}`;
            }

            let cmsStatic = {};
            // On check si la page est une page static ou la page home (route = "/")
            if (req.query._slug === 'home') {
                if (req.req) {
                    return req.res.redirect(`/${req.query.lang ? (req.query.lang + '/' + params) : params}`);
                }
                window.location.pathname = `/${req.query.lang ? (req.query.lang + '/' + params) : params}`;
                return;
            }
            if (_slug === undefined) _slug = 'home';
            cmsStatic = await axios.post(`${getAPIUrl(req)}v2/static${params}`, {
                lang     : req.query.lang || lang,
                PostBody : { limit: 1, filter: { [`translation.${req.query.lang || lang}.slug`]: _slug }, structure: { title: 1, metaDesc: 1 } },
            });

            if (cmsStatic.err || cmsStatic.data === null || cmsStatic.data === '') {
                console.error('\x1b[31m%s\x1b[0m', `Error: {pageStatic: ${_slug}}`);
            }

            let isEmpty = false;
            let notFound = false;
            let datasComponentsStatic = null;

            // On envoie une requete a l'api static afin de recupérer le contenu de la page statique
            // Si cmsStatic.data existe mais que content est vide, on affiche le message d'erreur avec isEmpty à true;
            if (cmsStatic.data && !cmsStatic.data.content) {
                isEmpty = true;
                notFound = false;
            }
            // L'url de la page n'est pas valide
            if (!cmsStatic.data) {
                isEmpty = true;
                notFound = true;
            }
            if (!isEmpty) {
                datasComponentsStatic = {
                    [`nsCms_${_slug}`] : { ...cmsStatic.data },
                };
                datasComponentsStatic = await componentLoader(
                    cmsStatic.data,
                    datasComponentsStatic,
                    getAPIUrl(req),
                    req.query.lang || lang,
                );
            }
            return {
                isEmpty,
                notFound,
                ...datasComponentsStatic,
                ...initData,
                url         : req.query,
                query       : req.query,
                nsLanguages : langs.data || [],
            };
        } catch (error) {
            console.error(error);
            return error;
        }
    };
    constructor(props) {
        super(props);
        this.state = {
            ...props,
        };
        this.cssHook = '';
        this.jsxHook = undefined;
    }
    static childContextTypes = {
        getPageState : PropTypes.func,
    };

    getChildContext() {
        return {
            getPageState : () => this.state,
        };
    }

    componentWillReceiveProps(props) {
        this.setState({ ...props });
    }


    onLangChange = (lang, Router) => {
        const defaultCode = this.props.nsLanguages.find(l => l.defaultLanguage === true).code;
        const newSlug = this.state[`nsCms_${this.props.router.query._slug || 'home'}`].slug[lang];

        const params = { _slug: newSlug };
        if (lang !== defaultCode && newSlug) {
            params.lang = lang;
        }

        Router.pushRoute('staticI18n', params).then(() => {
            if (newSlug === 'home') window.location.pathname = Router.router.asPath;
        });
    }

    render() {
        const _slug = this.state.url.query._slug ? this.state.url.query._slug :  'home';
        return (
            <div>
                <header
                    dangerouslySetInnerHTML={{
                        __html : this.state.oCmsHeader.content,
                    }}
                />
                {this.state.isEmpty ? (
                    ''
                ) : (
                    <div
                        {...this.props}
                        dangerouslySetInnerHTML={{
                            __html : this.state[`nsCms_${_slug}`].content,
                        }}
                    />
                )}
                {this.jsxHook}
                <footer
                    dangerouslySetInnerHTML={{
                        __html : this.state.oCmsFooter.content,
                    }}
                />
            </div>
        );
    }
}
