import React, { Component } from 'react';
import PropTypes from 'prop-types';
import axios from 'axios';
import { simplifyPath, initPage, base64ToString } from '../lib/helpers';
import getAPIUrl from '../lib/generateAPIUrl';
import jwtManager from '../lib/jwtManager';

const defaultItemPerPage = 15;

export const NSSearchLabel = {
    previous : props => (
        <svg width="6px" height="8px" viewBox="0 0 35 45" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink">
            <defs>
                <path id="a1" d="M0 0h35v45H0z" />
            </defs>
            <g transform="matrix(-1 0 0 1 35 0)" fill="none" fillRule="evenodd">
                <mask id="b1" fill="#fff">
                    <use xlinkHref="#a1" />
                </mask>
                <path d="M.023 3.345L5.438 42.64c.106.758.553 1.372 1.335 1.828.785.457 1.662.62 2.637.49.969-.137 1.769-.528 2.4-1.18l22.376-23.092c.63-.654.898-1.357.79-2.118-.102-.758-.548-1.37-1.333-1.828L5.85.534C5.065.076 4.188-.089 3.22.045 2.246.18 1.444.572.815 1.225.18 1.878-.083 2.58.023 3.346" fill={props.color} mask="url(#b1)" />
            </g>
        </svg>),
    next : props => (
        <svg width="6px" height="8px" viewBox="0 0 35 45" xmlns="http://www.w3.org/2000/svg" xmlnsXlink="http://www.w3.org/1999/xlink">
            <defs>
                <path d="M0 0h35v45H0z" />
            </defs>
            <g fill="none" fillRule="evenodd">
                <mask fill="#fff">
                    <use xlinkHref="#a2" />
                </mask>
                <path
                    d="M.023 3.345L5.438 42.64c.106.758.553 1.372 1.335 1.828.785.457 1.662.62 2.637.49.969-.137 1.769-.528 2.4-1.18l22.376-23.092c.63-.654.898-1.357.79-2.118-.102-.758-.548-1.37-1.333-1.828L5.85.534C5.065.076 4.188-.089 3.22.045 2.246.18 1.444.572.815 1.225.18 1.878-.083 2.58.023 3.346"
                    fill={props.color} mask="url(#b2)"
                />
            </g>
        </svg>),
};

export class NSSearch extends Component {
    static childContextTypes = {
        getPageState : PropTypes.func,
        onLangChange : PropTypes.func,
    };

    static defaultProps = {
        contentHtml : {
            content : '',
        },
        search     : '',
        products   : [],
        oCmsHeader : {
            content : '',
        },
        productsList : [],
        filters      : [],
        min          : 0,
        max          : 0,
        count        : 0,
        oCmsFooter   : {
            content : '',
        },
        isEmpty : true,
    };

    constructor(props) {
        super(props);
        this.state = {
            ...props,
            itemsPerPages : defaultItemPerPage,
        };
    }

    getChildContext() {
        return {
            getPageState : () => this.state,
            onLangChange : lang => this.onLangChange(lang),
        };
    }

    onPageChange = async (page, filters = {}) => {
        const { lang, search, sort } = this.state;
        let sorting;
        let sortField;
        if (sort) {
            sorting = { score: { $meta: 'textScore' } };
            sortField = Object.keys(sort)[0];
            if (sortField !== 'pos') {
                sorting = sort;
            }
        }

        if (page.selected !== undefined) {
            if (page.name && page.name === 'onPaginationChange') {
                // scrollTo est un Number qui indiquera a combien de pixel du top doit remonter le scroll
                window.scroll({ top: page.scrollTo ? page.scrollTo : 0, behavior: 'smooth' });
            }
            page = page.selected + 1;
        }
        if (typeof window !== 'undefined') {
            window.localStorage.setItem('page', JSON.stringify({ location: 'search', page }));
        }
        const products  = await axios.post(`${getAPIUrl()}v2/products/true`, {
            lang,
            PostBody : {
                filter : {
                    active   : true, _visible : true, $text    : { $search: search }, ...filters,
                },
                structure : sortField && sortField === 'pos' && sort ? { score: { $meta: 'textScore' }, canonical: 1, universe: 1 } : { canonical: 1, universe: 1 },
                sort      : sorting,
                page      : JSON.parse(window.localStorage.getItem('page')).page,
                limit     : this.state.itemsPerPages,
            },
        });

        this.setState({
            products    : products.data.datas,
            count       : products.data.count,
            min         : products.data.min,
            max         : products.data.max,
            filtersData : products.data.filters,
            current     : page,
            filters,
        });
    };

    static getInitialProps = async function (req) {
        // Gestion de la langue et du slug
        const langs                 = [];// await axios.post(`${getAPIUrl(req)}v2/languages`, { PostBody: { limit: 99 } });
        const lang                  = 'fr';// req.query.lang || langs.data.datas.find(l => l.defaultLanguage === true).code;
        const search = req.query.search;
        const page = req.query.page !== undefined ? req.query.page : 1;
        let baseUrl = '';

        if (req.req) {
            baseUrl = `${req.req.protocol}://${req.req.headers.host}${req.query.lang ? `/${req.query.lang}` : ''}/search/${search}`;
        } else {
            baseUrl = `${window.location.origin}${req.query.lang ? `/${req.query.lang}` : ''}/search/${search}`;
        }

        try {
            // On charge la page static pouvant contenir plusieurs BlocCMS comportant eu même plusieurs composant a charger
            const isEmpty = false;
            const notFound = false;
            // on récupère l'information pour voir les prix en HT ou en TTC
            const taxDisplay = jwtManager.getTaxDisplay(req);
            // on recupére le block cms ayant pour id "header", un block cms peut contenir plusieurs composant
            const initData = await initPage(req, lang);
            // On envoie une requete a l api produits afin de recupérer les produits de la recherche
            const products  = await axios.post(`${getAPIUrl(req)}v2/products/true`, {
                lang,
                PostBody : {
                    filter    : { active: true, _visible: true, $text: { $search: search } },
                    structure : { score: { $meta: 'textScore' }, canonical: 1 },
                    sort      : { score: { $meta: 'textScore' } },
                    page      : typeof window !== 'undefined' && window.localStorage.getItem('page') && JSON.parse(window.localStorage.getItem('page')).location === 'search' ? JSON.parse(window.localStorage.getItem('page')).page : page,
                    limit     : defaultItemPerPage,
                },
            });
            return {
                isEmpty,
                notFound,
                search,
                taxDisplay,
                ...initData,
                url         : { asPath: req.asPath },
                query       : req.query,
                products    : products.data.datas,
                count       : products.data.count,
                min         : products.data.min,
                max         : products.data.max,
                filtersData : products.data.filters,
                filters     : {
                    $and : [{
                        $or : [
                            {
                                [`price.${taxDisplay}.normal`] : {
                                    $gte : products.data.min[taxDisplay] || 0,
                                    $lte : products.data.max[taxDisplay] || 0
                                }
                            }, {
                                [`price.${taxDisplay}.special`] : {
                                    $gte : products.data.min[taxDisplay] || 0,
                                    $lte : products.data.max[taxDisplay] || 0
                                }
                            }
                        ]
                    }]
                },
                current     : page,
                baseUrl,
                nsLanguages : langs.data,
                lang,
            };
        } catch (error) {
            console.error(error);
            return error;
        }
    };

    UNSAFE_componentWillMount() {
        // Si un seul produit est trouvé alors on va directement sur la page du produit
        if (typeof window !== 'undefined' && this.props.products.length === 1) {
            window.location.pathname = this.props.products[0].canonical;
        }
    }

    handleSort = ({ field, sortValue }, value, filters = {}) => {
        this.setState({ sort: { [`${field}`]: Number(sortValue) }, selectedSort: value }, () => {
            this.onPageChange(1, filters);
        });
    };

    render() {
        return (
            <div>


A surcharger
            </div>
        );
    }
}
