/* global document, window, localStorage */

import axios from 'axios';
import 'aql-utils/themeIndex';

// A garder dans l'ordre alphabétique en fonction du nom du composant ou de la page SVP
// Import des pages
import { NSArticle } from '../pages/NSArticle';
import { NSBlogArticle } from '../pages/NSBlogArticle';
import { NSCategory } from '../pages/NSCategory';
import { NSPage } from '../pages/NSPage';
import { NSSearch, NSSearchLabel } from '../pages/NSSearch';

// Import des composants
import _NSconfig from '../components/_NSconfig';
import { NSAccount } from '../components/NSAccount';
import { NSAddress } from '../components/NSAddress';
import { NSAddressMultiple } from '../components/NSAddressMultiple';
import { NSAgenda } from '../components/NSAgenda';
import { NSArticles } from '../components/NSArticles';
import { NSBlockSlider } from '../components/NSBlockSlider';
import { NSBlogArticles } from '../components/NSBlogArticles';
import { NSBreadcrumb } from '../components/NSBreadcrumb';
import { NSButtonLoginAccount } from '../components/NSButtonLoginAccount';
import { NSCart } from '../components/NSCart';
import { NSCartBillingStep } from '../components/NSCartBillingStep';
import { NSCartLogin } from '../components/NSCartLogin';
import { NSCartOrderFailStep } from '../components/NSCartOrderFailStep';
import { NSCartOrderSuccessStep } from '../components/NSCartOrderSuccessStep';
import { NSCartPaymentStep } from '../components/NSCartPaymentStep';
import { NSCartProductCounter } from '../components/NSCartProductCounter';
import { NSCartStep } from '../components/NSCartStep';
import { NSCartSummaryStep } from '../components/NSCartSummaryStep';
import { NSCMS } from '../components/NSCMS';
import { NSCodePromo } from '../components/NSCodePromo';
import { NSContact } from '../components/NSContact';
import { NSCookieBanner } from '../components/NSCookieBanner';
import { NSCrossSelling } from '../components/NSCrossSelling';
import { NSDetailOrder } from '../components/NSDetailOrder';
import { NSDrawStars } from '../components/NSDrawStars';
import { NSFilters } from '../components/NSFilters';
import { NSGallery } from '../components/NSGallery';
import { NSGoToTopButton } from '../components/NSGoToTopButton';
import { NSLoadingSpinner } from '../components/NSLoadingSpinner';
import { NSLogin } from '../components/NSLogin';
import { NSMenu } from '../components/NSMenu';
import { NSNewsletter } from '../components/NSNewsletter';
import { NSOrderList } from '../components/NSOrderList';
import { NSProductCard } from '../components/NSProductCard';
import { NSProductStock } from '../components/NSProductStock';
import { NSRegister } from '../components/NSRegister';
import { NSSearchBar } from '../components/NSSearchBar';
import { NSSlider } from '../components/NSSlider';
import { NSToast } from '../components/NSToast';

// Import des libs
import { CartLib } from '../lib/CartLib';
import componentLoader from '../lib/componentLoader';
import generateAPIUrl from '../lib/generateAPIUrl';
import jwtManager from '../lib/jwtManager';
import {
    last, hexToRGBA, shadeColor, simplifyPath, initPage, isServer, getLangPrefix, scrollToTop, getProductUrl, has, base64ToString, stringToBase64, getUrlParams, mergeRecursive
} from '../lib/helpers';
import { isAuth, setAxiosAuthorization } from '../lib/isAuth';
import statusColor from '../lib/statusColor';
import assets from '../lib/loadAssets';

export {
    // Export des pages
    NSArticle,
    NSBlogArticle,
    NSCategory,
    NSPage,
    NSSearch,
    NSSearchLabel,

    // Export des composants
    _NSconfig,
    NSAccount,
    NSAddress,
    NSAddressMultiple,
    NSAgenda,
    NSArticles,
    NSBlockSlider,
    NSBlogArticles,
    NSBreadcrumb,
    NSButtonLoginAccount,
    NSCart,
    NSCartBillingStep,
    NSCartLogin,
    NSCartOrderFailStep,
    NSCartOrderSuccessStep,
    NSCartPaymentStep,
    NSCartProductCounter,
    NSCartStep,
    NSCartSummaryStep,
    NSCMS,
    NSCodePromo,
    NSContact,
    NSCookieBanner,
    NSCrossSelling,
    NSDetailOrder,
    NSDrawStars,
    NSFilters,
    NSGallery,
    NSGoToTopButton,
    NSLoadingSpinner,
    NSLogin,
    NSMenu,
    NSNewsletter,
    NSOrderList,
    NSProductCard,
    NSProductStock,
    NSRegister,
    NSSearchBar,
    NSSlider,
    NSToast,

    // Export des libs
    CartLib,
    componentLoader,
    generateAPIUrl,
    jwtManager,
    initPage,
    last,
    hexToRGBA,
    shadeColor,
    isServer,
    getLangPrefix,
    simplifyPath,
    isAuth,
    statusColor,
    scrollToTop,
    getProductUrl,
    has,
    base64ToString,
    stringToBase64,
    getUrlParams,
    mergeRecursive,
    assets
};

let countInterceptor = 0;

function showSpinner() {
    if (typeof window !== 'undefined') document.body.classList.add('loading-indicator');
}
function hideSpinner() {
    if (typeof window !== 'undefined') document.body.classList.remove('loading-indicator');
}
function setJWT(token) {
    const jwt = jwtManager.get();
    if (jwt) {
        axios.defaults.headers.common.Authorization = jwt;
    }
}

axios.interceptors.request.use((config) => {
    // spinning start to show
    // UPDATE: Add this code to show global loading indicator
    if (typeof window !== 'undefined') {
        const requestSent = new window.CustomEvent('requestSent', { detail: {} });
        window.dispatchEvent(requestSent);
    }
    return config;
}, (error) => {
    if (typeof window !== 'undefined') {
        const requestSent = new window.CustomEvent('requestSent', { detail: {} });
        window.dispatchEvent(requestSent);
    }
    Promise.reject(error);
});

axios.interceptors.response.use((response) => {
    // spinning hide
    // UPDATE: Add this code to hide global loading indicator
    if (typeof window !== 'undefined') {
        const responseReceive = new window.CustomEvent('responseReceive', { detail: {} });
        window.dispatchEvent(responseReceive);
    }
    return response;
}, (error) => {
    if (typeof window !== 'undefined') {
        const responseReceive = new window.CustomEvent('responseReceive', { detail: {} });
        window.dispatchEvent(responseReceive);
    }
    if (error && error.response && error.response.data && error.response.request && error.response.data.message && error.response.data.reponseURL) {
        if (error.response.status < 300) {
            NSToast.success(error.response.data.message);
        } else if (error.response.status < 400) {
            NSToast.warn(error.response.data.message);
        } else {
            switch (error.response.data.code) {
            case 'invalid_objectid_error':
                if (typeof window !== 'undefined') {
                    window.localStorage.removeItem('cart_id');
                }
                break;
            case 'NOT_FOUND':
                if (typeof window !== 'undefined') {
                    window.localStorage.removeItem('cart_id');
                }
                break;
            case 'NotFound':
                if (error.response.request.reponseURL.indexOf('/cart/') > -1 && typeof window !== 'undefined') {
                    window.localStorage.removeItem('cart_id');
                }
                break;
            default:
                NSToast.error(error.response.data.message);
            }
        }
    }
    return Promise.reject(error);
});

setJWT();

if (typeof window !== 'undefined') {
    window.addEventListener('requestSent', async (e) => {
        countInterceptor++;
        showSpinner();
    });
    window.addEventListener('responseReceive', async (e) => {
        countInterceptor--;
        if (countInterceptor === 0) hideSpinner();
    });
    window.addEventListener('setJWT', (e) => {
        setJWT(e.detail.jwt);
    });
}

